pub unsafe fn __tile_loadd(
dst: *mut __tile1024i,
base: *const u8,
stride: usize,
)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics)Expand description
Load tile rows from memory specified by base address and stride into destination tile dst. The shape
of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.