W3cubDocs

/Rust

Function min_by_key

pub fn min_by_key<T, F, K>(v1: T, v2: T, f: F) -> Twhere
    F: FnMut(&T) -> K,
    K: Ord,

Returns the element that gives the minimum value from the specified function.

Returns the first argument if the comparison determines them to be equal.

Examples

use std::cmp;

let result = cmp::min_by_key(2, -1, |x: &i32| x.abs());
assert_eq!(result, -1);

let result = cmp::min_by_key(2, -3, |x: &i32| x.abs());
assert_eq!(result, 2);

let result = cmp::min_by_key(1, -1, |x: &i32| x.abs());
assert_eq!(result, 1);

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/cmp/fn.min_by_key.html