pub struct UnorderedKeyError {}
btree_cursors #107540)
Error type returned by CursorMut::insert_before and CursorMut::insert_after if the key being inserted is not properly ordered with regards to adjacent keys.
impl Clone for UnorderedKeyError
fn clone(&self) -> UnorderedKeyError
fn clone_from(&mut self, source: &Self)
source. Read more
impl Debug for UnorderedKeyError
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Display for UnorderedKeyError
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Error for UnorderedKeyError
fn source(&self) -> Option<&(dyn Error + 'static)>
fn description(&self) -> &str
fn cause(&self) -> Option<&dyn Error>
fn provide<'a>(&'a self, request: &mut Request<'a>)
error_generic_member_access #99301)
impl PartialEq for UnorderedKeyError
fn eq(&self, other: &UnorderedKeyError) -> bool
self and other values to be equal, and is used by ==.fn ne(&self, other: &Rhs) -> bool
!=. The default implementation is almost always sufficient, and should not be overridden without very good reason.impl Eq for UnorderedKeyError
impl StructuralPartialEq for UnorderedKeyError
impl Freeze for UnorderedKeyError
impl RefUnwindSafe for UnorderedKeyError
impl Send for UnorderedKeyError
impl Sync for UnorderedKeyError
impl Unpin for UnorderedKeyError
impl UnwindSafe for UnorderedKeyError
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> CloneToUninit for Twhere
T: Clone,unsafe fn clone_to_uninit(&self, dest: *mut u8)
clone_to_uninit #126799)
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToOwned for Twhere
T: Clone,type Owned = T
fn to_owned(&self) -> T
fn clone_into(&self, target: &mut T)
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/collections/btree_map/struct.UnorderedKeyError.html