pub fn home_dir() -> Option<PathBuf>
Returns the path of the current user’s home directory if known.
This may return None if getting the directory fails or if the platform does not have user home directories.
For storing user data and configuration it is often preferable to use more specific directories. For example, XDG Base Directories on Unix or the LOCALAPPDATA and APPDATA environment variables on Windows.
getpwuid_r function using the UID of the current user. An empty home directory field returned from the getpwuid_r function is considered to be a valid value.None if the current user has no entry in the /etc/passwd file.GetUserProfileDirectory is used to return the path. This may change in the future.In UWP (Universal Windows Platform) targets this function is unimplemented and always returns None.
Before Rust 1.85.0, this function used to return the value of the ‘HOME’ environment variable on Windows, which in Cygwin or Mingw environments could return non-standard paths like /home/you instead of C:\Users\you.
use std::env;
match env::home_dir() {
Some(path) => println!("Your home directory, probably: {}", path.display()),
None => println!("Impossible to get your home dir!"),
}
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/env/fn.home_dir.html