pub struct Display<'a> { /* private fields */ }
Helper struct for safely printing an OsStr with format! and {}.
An OsStr might contain non-Unicode data. This struct implements the Display trait in a way that mitigates that. It is created by the display method on OsStr. This may perform lossy conversion, depending on the platform. If you would like an implementation which escapes the OsStr please use Debug instead.
use std::ffi::OsStr;
let s = OsStr::new("Hello, world!");
println!("{}", s.display());impl Debug for Display<'_>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Display for Display<'_>
impl<'a> Freeze for Display<'a>
impl<'a> RefUnwindSafe for Display<'a>
impl<'a> Send for Display<'a>
impl<'a> Sync for Display<'a>
impl<'a> Unpin for Display<'a>
impl<'a> UnwindSafe for Display<'a>
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/ffi/os_str/struct.Display.html