W3cubDocs

/Rust

Struct VaListImpl

pub struct VaListImpl<'f> { /* private fields */ }
🔬This is a nightly-only experimental API. (c_variadic #44930)

x86_64 ABI implementation of a va_list.

Implementations

impl<'f> VaListImpl<'f>
pub fn as_va_list<'a>(&'a mut self) -> VaList<'a, 'f>
🔬This is a nightly-only experimental API. (c_variadic #44930)

Converts a VaListImpl into a VaList that is binary-compatible with C’s va_list.

impl<'f> VaListImpl<'f>
pub unsafe fn arg<T>(&mut self) -> Twhere
    T: VaArgSafe,
🔬This is a nightly-only experimental API. (c_variadic #44930)

Advance to and read the next variable argument.

Safety

This function is only sound to call when:

  • there is a next variable argument available.
  • the next argument’s type must be ABI-compatible with the type T.
  • the next argument must have a properly initialized value of type T.

Calling this function with an incompatible type, an invalid value, or when there are no more variable arguments, is unsound.

pub unsafe fn with_copy<F, R>(&self, f: F) -> Rwhere
    F: for<'copy> FnOnce(VaList<'copy, 'f>) -> R,
🔬This is a nightly-only experimental API. (c_variadic #44930)

Copies the va_list at the current location.