W3cubDocs

/Rust

Trait VaArgSafe

pub unsafe trait VaArgSafe: Sealed { }
🔬This is a nightly-only experimental API. (c_variadic #44930)

Types that are valid to read using VaListImpl::arg.

Safety

The standard library implements this trait for primitive types that are expected to have a variable argument application-binary interface (ABI) on all platforms.

When C passes variable arguments, integers smaller than c_int and floats smaller than c_double are implicitly promoted to c_int and c_double respectively. Implementing this trait for types that are subject to this promotion rule is invalid.

Implementors

impl VaArgSafe for f64
impl VaArgSafe for i32
impl VaArgSafe for i64
impl VaArgSafe for isize
impl VaArgSafe for u32
impl VaArgSafe for u64
impl VaArgSafe for usize
impl<T> VaArgSafe for *const T
impl<T> VaArgSafe for *mut T

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/ffi/trait.VaArgSafe.html