pub type c_size_t = usize;
c_size_t #88345)
Equivalent to C’s size_t type, from stddef.h (or cstddef for C++).
This type is currently always usize, however in the future there may be platforms where this is not the case.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/ffi/type.c_size_t.html