pub struct Arguments<'a> { /* private fields */ }
This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.
The format_args! macro will safely create an instance of this structure. The macro validates the format string at compile-time so usage of the write() and format() functions can be safely performed.
You can use the Arguments<'a> that format_args! returns in Debug and Display contexts as seen below. The example also shows that Debug and Display format to the same thing: the interpolated format string in format_args!.
let debug = format!("{:?}", format_args!("{} foo {:?}", 1, 2));
let display = format!("{}", format_args!("{} foo {:?}", 1, 2));
assert_eq!("1 foo 2", display);
assert_eq!(display, debug);impl<'a> Arguments<'a>
pub const fn from_str(s: &'static str) -> Arguments<'a>
fmt_arguments_from_str #148905)
Create a fmt::Arguments object for a single static string.
Formatting this fmt::Arguments will just produce the string as-is.
pub const fn as_str(&self) -> Option<&'static str>
Gets the formatted string, if it has no arguments to be formatted at runtime.
This can be used to avoid allocations in some cases.
For format_args!("just a literal"), this function is guaranteed to return Some("just a literal").
For most cases with placeholders, this function will return None.
However, the compiler may perform optimizations that can cause this function to return Some(_) even if the format string contains placeholders. For example, format_args!("Hello, {}!", "world") may be optimized to format_args!("Hello, world!"), such that as_str() returns Some("Hello, world!").
The behavior for anything but the trivial case (without placeholders) is not guaranteed, and should not be relied upon for anything other than optimization.
use std::fmt::Arguments;
fn write_str(_: &str) { /* ... */ }
fn write_fmt(args: &Arguments<'_>) {
if let Some(s) = args.as_str() {
write_str(s)
} else {
write_str(&args.to_string());
}
}assert_eq!(format_args!("hello").as_str(), Some("hello"));
assert_eq!(format_args!("").as_str(), Some(""));
assert_eq!(format_args!("{:?}", std::env::current_dir()).as_str(), None);impl<'a> Clone for Arguments<'a>
fn clone(&self) -> Arguments<'a>
fn clone_from(&mut self, source: &Self)
source. Read more
impl Debug for Arguments<'_>
fn fmt(&self, fmt: &mut Formatter<'_>) -> Result<(), Error>
impl Display for Arguments<'_>
fn fmt(&self, fmt: &mut Formatter<'_>) -> Result<(), Error>
impl<'a> Copy for Arguments<'a>
impl !Send for Arguments<'_>
impl !Sync for Arguments<'_>
impl<'a> Freeze for Arguments<'a>
impl<'a> RefUnwindSafe for Arguments<'a>
impl<'a> Unpin for Arguments<'a>
impl<'a> UnwindSafe for Arguments<'a>
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> CloneToUninit for Twhere
T: Clone,unsafe fn clone_to_uninit(&self, dest: *mut u8)
clone_to_uninit #126799)
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToOwned for Twhere
T: Clone,type Owned = T
fn to_owned(&self) -> T
fn clone_into(&self, target: &mut T)
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/fmt/struct.Arguments.html