pub enum TryLockError {
Error(Error),
WouldBlock,
}
An enumeration of possible errors which can occur while trying to acquire a lock from the try_lock method and try_lock_shared method on a File.
Error(Error)
The lock could not be acquired due to an I/O error on the file. The standard library will not return an ErrorKind::WouldBlock error inside TryLockError::Error
WouldBlock
The lock could not be acquired at this time because it is held by another handle/process.
impl Debug for TryLockError
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Display for TryLockError
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Error for TryLockError
fn source(&self) -> Option<&(dyn Error + 'static)>
fn description(&self) -> &str
fn cause(&self) -> Option<&dyn Error>
fn provide<'a>(&'a self, request: &mut Request<'a>)
error_generic_member_access #99301)
impl From<TryLockError> for Error
fn from(err: TryLockError) -> Error
impl Freeze for TryLockError
impl !RefUnwindSafe for TryLockError
impl Send for TryLockError
impl Sync for TryLockError
impl Unpin for TryLockError
impl !UnwindSafe for TryLockError
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/fs/enum.TryLockError.html