Struct DefaultHasher

struct DefaultHasher(_)

The default Hasher used by RandomState.

The internal algorithm is not specified, and so it and its hashes should not be relied upon over releases.

Implementations

impl DefaultHasher

const fn new() -> DefaultHasher

Creates a new DefaultHasher.

This hasher is not guaranteed to be the same as all other DefaultHasher instances, but is the same as all other DefaultHasher instances created through new or default.

impl Clone for DefaultHasher

fn clone(self: &Self) -> DefaultHasher

impl Debug for DefaultHasher

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for DefaultHasher

fn default() -> DefaultHasher

Creates a new DefaultHasher using new. See its documentation for more.

impl Freeze for DefaultHasher

impl Hasher for DefaultHasher

fn write(self: &mut Self, msg: &[u8])
fn write_str(self: &mut Self, s: &str)
fn finish(self: &Self) -> u64

impl RefUnwindSafe for DefaultHasher

impl Send for DefaultHasher

impl Sync for DefaultHasher

impl Unpin for DefaultHasher

impl UnsafeUnpin for DefaultHasher

impl UnwindSafe for DefaultHasher

impl<T> Any for DefaultHasher

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DefaultHasher

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DefaultHasher

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DefaultHasher

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DefaultHasher

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DefaultHasher

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DefaultHasher

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DefaultHasher

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DefaultHasher

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>