pub struct DefaultHasher(/* private fields */);
The default Hasher used by RandomState.
The internal algorithm is not specified, and so it and its hashes should not be relied upon over releases.
impl DefaultHasher
pub fn new() -> DefaultHasher
Creates a new DefaultHasher.
This hasher is not guaranteed to be the same as all other DefaultHasher instances, but is the same as all other DefaultHasher instances created through new or default.
impl Clone for DefaultHasher
fn clone(&self) -> DefaultHasher
fn clone_from(&mut self, source: &Self)
source. Read more
impl Debug for DefaultHasher
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Default for DefaultHasher
fn default() -> DefaultHasher
Creates a new DefaultHasher using new. See its documentation for more.
impl Hasher for DefaultHasher
fn write(&mut self, msg: &[u8])
Hasher. Read more
fn write_str(&mut self, s: &str)
hasher_prefixfree_extras #96762)
str into this hasher. Read more
fn finish(&self) -> u64
fn write_u8(&mut self, i: u8)
u8 into this hasher.fn write_u16(&mut self, i: u16)
u16 into this hasher.fn write_u32(&mut self, i: u32)
u32 into this hasher.fn write_u64(&mut self, i: u64)
u64 into this hasher.fn write_u128(&mut self, i: u128)
u128 into this hasher.fn write_usize(&mut self, i: usize)
usize into this hasher.fn write_i8(&mut self, i: i8)
i8 into this hasher.fn write_i16(&mut self, i: i16)
i16 into this hasher.fn write_i32(&mut self, i: i32)
i32 into this hasher.fn write_i64(&mut self, i: i64)
i64 into this hasher.fn write_i128(&mut self, i: i128)
i128 into this hasher.fn write_isize(&mut self, i: isize)
isize into this hasher.fn write_length_prefix(&mut self, len: usize)
hasher_prefixfree_extras #96762)
impl Freeze for DefaultHasher
impl RefUnwindSafe for DefaultHasher
impl Send for DefaultHasher
impl Sync for DefaultHasher
impl Unpin for DefaultHasher
impl UnwindSafe for DefaultHasher
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> CloneToUninit for Twhere
T: Clone,unsafe fn clone_to_uninit(&self, dest: *mut u8)
clone_to_uninit #126799)
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToOwned for Twhere
T: Clone,type Owned = T
fn to_owned(&self) -> T
fn clone_into(&self, target: &mut T)
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/hash/struct.DefaultHasher.html