pub struct RandomState { /* private fields */ }
RandomState is the default state for HashMap types.
A particular instance RandomState will create the same instances of Hasher, but the hashers created by two different RandomState instances are unlikely to produce the same result for the same values.
use std::collections::HashMap; use std::hash::RandomState; let s = RandomState::new(); let mut map = HashMap::with_hasher(s); map.insert(1, 2);
impl RandomState
pub fn new() -> RandomState
Constructs a new RandomState that is initialized with random keys.
use std::hash::RandomState; let s = RandomState::new();
impl BuildHasher for RandomState
type Hasher = DefaultHasher
fn build_hasher(&self) -> DefaultHasher
fn hash_one<T>(&self, x: T) -> u64where
T: Hash,
Self: Sized,
Self::Hasher: Hasher,impl Clone for RandomState
fn clone(&self) -> RandomState
fn clone_from(&mut self, source: &Self)
source. Read more
impl Debug for RandomState
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Default for RandomState
fn default() -> RandomState
Constructs a new RandomState.
impl Freeze for RandomState
impl RefUnwindSafe for RandomState
impl Send for RandomState
impl Sync for RandomState
impl Unpin for RandomState
impl UnwindSafe for RandomState
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> CloneToUninit for Twhere
T: Clone,unsafe fn clone_to_uninit(&self, dest: *mut u8)
clone_to_uninit #126799)
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToOwned for Twhere
T: Clone,type Owned = T
fn to_owned(&self) -> T
fn clone_into(&self, target: &mut T)
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/hash/struct.RandomState.html