pub enum AtomicOrdering {
Relaxed = 0,
Release = 1,
Acquire = 2,
AcqRel = 3,
SeqCst = 4,
}
core_intrinsics)
A type for atomic ordering parameters for intrinsics. This is a separate type from atomic::Ordering so that we can make it ConstParamTy and fix the values used here without a risk of leaking that to stable code.
Relaxed = 0
core_intrinsics)
Release = 1
core_intrinsics)
Acquire = 2
core_intrinsics)
AcqRel = 3
core_intrinsics)
SeqCst = 4
core_intrinsics)
impl Debug for AtomicOrdering
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
impl PartialEq for AtomicOrdering
fn eq(&self, other: &AtomicOrdering) -> bool
self and other values to be equal, and is used by ==.fn ne(&self, other: &Rhs) -> bool
!=. The default implementation is almost always sufficient, and should not be overridden without very good reason.impl ConstParamTy_ for AtomicOrdering
impl Eq for AtomicOrdering
impl StructuralPartialEq for AtomicOrdering
impl Freeze for AtomicOrdering
impl RefUnwindSafe for AtomicOrdering
impl Send for AtomicOrdering
impl Sync for AtomicOrdering
impl Unpin for AtomicOrdering
impl UnwindSafe for AtomicOrdering
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/enum.AtomicOrdering.html