W3cubDocs

/Rust

Function aggregate_raw_ptr

pub const fn aggregate_raw_ptr<P, D, M>(data: D, meta: M) -> Pwhere
    P: BuiltinDeref,
    <P as BuiltinDeref>::Pointee: Pointee<Metadata = M>,
🔬This is a nightly-only experimental API. (core_intrinsics)

Lowers in MIR to Rvalue::Aggregate with AggregateKind::RawPtr.

This is used to implement functions like slice::from_raw_parts_mut and ptr::from_raw_parts in a way compatible with the compiler being able to change the possible layouts of pointers.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.aggregate_raw_ptr.html