W3cubDocs

/Rust

Function atomic_cxchgweak

pub unsafe fn atomic_cxchgweak<T, const ORD_SUCC: AtomicOrdering, const ORD_FAIL: AtomicOrdering>(
    _dst: *mut T,
    _old: T,
    _src: T,
) -> (T, bool)where
    T: Copy,
🔬This is a nightly-only experimental API. (core_intrinsics)

Stores a value if the current value is the same as the old value. T must be an integer or pointer type. The comparison may spuriously fail.

The stabilized version of this intrinsic is available on the atomic types via the compare_exchange_weak method. For example, AtomicBool::compare_exchange_weak.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.atomic_cxchgweak.html