W3cubDocs

/Rust

Function atomic_min

pub unsafe fn atomic_min<T, const ORD: AtomicOrdering>(dst: *mut T, src: T) -> Twhere
    T: Copy,
🔬This is a nightly-only experimental API. (core_intrinsics)

Minimum with the current value using a signed comparison. T must be a signed integer type.

The stabilized version of this intrinsic is available on the atomic signed integer types via the fetch_min method. For example, AtomicI32::fetch_min.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.atomic_min.html