W3cubDocs

/Rust

Function atomic_singlethreadfence

pub unsafe fn atomic_singlethreadfence<const ORD: AtomicOrdering>()
🔬This is a nightly-only experimental API. (core_intrinsics)

An atomic fence for synchronization within a single thread.

The stabilized version of this intrinsic is available in atomic::compiler_fence.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.atomic_singlethreadfence.html