W3cubDocs

/Rust

Function atomic_umax

pub unsafe fn atomic_umax<T, const ORD: AtomicOrdering>(
    dst: *mut T,
    src: T,
) -> Twhere
    T: Copy,
🔬This is a nightly-only experimental API. (core_intrinsics)

Maximum with the current value using an unsigned comparison. T must be an unsigned integer type.

The stabilized version of this intrinsic is available on the atomic unsigned integer types via the fetch_max method. For example, AtomicU32::fetch_max.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.atomic_umax.html