pub const unsafe fn const_deallocate(_ptr: *mut u8, _size: usize, _align: usize)
core_intrinsics)
Deallocates a memory which allocated by intrinsics::const_allocate at compile time. At runtime, does nothing.
align argument must be a power of two. ptr is created in an another const, this intrinsic doesn’t deallocate it.ptr is pointing to a local variable, this intrinsic doesn’t deallocate it.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.const_deallocate.html