pub const fn contract_check_ensures<C, Ret>(cond: Option<C>, ret: Ret) -> Retwhere
C: Fn(&Ret) -> bool + Copy,
contracts_internals #128044)
Check if the post-condition cond has been met.
By default, if contract_checks is enabled, this will panic with no unwind if the condition returns false.
If cond is None, then no postcondition checking is performed.
Note that this function is a no-op during constant evaluation.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.contract_check_ensures.html