pub unsafe fn fadd_fast<T>(a: T, b: T) -> Twhere
T: Copy,
core_intrinsics)
Float addition that allows optimizations based on algebraic rules. Requires that inputs and output of the operation are finite, causing UB otherwise.
This intrinsic does not have a stable counterpart.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.fadd_fast.html