W3cubDocs

/Rust

Function fmul_fast

pub unsafe fn fmul_fast<T>(a: T, b: T) -> Twhere
    T: Copy,
🔬This is a nightly-only experimental API. (core_intrinsics)

Float multiplication that allows optimizations based on algebraic rules. Requires that inputs and output of the operation are finite, causing UB otherwise.

This intrinsic does not have a stable counterpart.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.fmul_fast.html