W3cubDocs

/Rust

Function type_name

pub const fn type_name<T>() -> &'static strwhere
    T: ?Sized,
🔬This is a nightly-only experimental API. (core_intrinsics)

Gets a static string slice containing the name of a type.

Note that, unlike most intrinsics, this can only be called at compile-time as backends do not have an implementation for it. The only caller (its stable counterpart) wraps this intrinsic call in a const block so that backends only see an evaluated constant.

The stabilized version of this intrinsic is core::any::type_name.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.type_name.html