W3cubDocs

/Rust

Function unchecked_funnel_shr

pub const unsafe fn unchecked_funnel_shr<T>(a: T, b: T, shift: u32) -> Twhere
    T: FunnelShift,
🔬This is a nightly-only experimental API. (funnel_shifts #145686)

Funnel Shift right.

Concatenates a and b (with a in the most significant half), creating an integer twice as wide. Then shift this integer right by shift (taken modulo the bit size of T), and extract the least significant half. If a and b are the same, this is equivalent to a rotate right operation.

It is undefined behavior if shift is greater than or equal to the bit size of T.

Safer versions of this intrinsic are available on the integer primitives via the funnel_shr method. For example, u32::funnel_shr

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.unchecked_funnel_shr.html