W3cubDocs

/Rust

Function va_copy

pub unsafe fn va_copy<'f>(dest: *mut VaListImpl<'f>, src: &VaListImpl<'f>)
🔬This is a nightly-only experimental API. (core_intrinsics)

Copies the current location of arglist src to the arglist dst.

Safety

You must check the following invariants before you call this function:

  • dest must be non-null and point to valid, writable memory.
  • dest must not alias src.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.va_copy.html