W3cubDocs

/Rust

Function variant_count

pub const fn variant_count<T>() -> usize
🔬This is a nightly-only experimental API. (core_intrinsics)

Returns the number of variants of the type T cast to a usize; if T has no variants, returns 0. Uninhabited variants will be counted.

Note that, unlike most intrinsics, this can only be called at compile-time as backends do not have an implementation for it. The only caller (its stable counterpart) wraps this intrinsic call in a const block so that backends only see an evaluated constant.

The to-be-stabilized version of this intrinsic is crate::mem::variant_count.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fn.variant_count.html