pub enum SimdAlign {
Unaligned = 0,
Element = 1,
Vector = 2,
}
core_intrinsics)
A type for alignment options for SIMD masked load/store intrinsics.
Unaligned = 0
core_intrinsics)
No alignment requirements on the pointer
Element = 1
core_intrinsics)
The pointer must be aligned to the element type of the SIMD vector
Vector = 2
core_intrinsics)
The pointer must be aligned to the SIMD vector type
impl Debug for SimdAlign
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
impl PartialEq for SimdAlign
fn eq(&self, other: &SimdAlign) -> bool
self and other values to be equal, and is used by ==.fn ne(&self, other: &Rhs) -> bool
!=. The default implementation is almost always sufficient, and should not be overridden without very good reason.impl ConstParamTy_ for SimdAlign
impl Eq for SimdAlign
impl StructuralPartialEq for SimdAlign
impl Freeze for SimdAlign
impl RefUnwindSafe for SimdAlign
impl Send for SimdAlign
impl Sync for SimdAlign
impl Unpin for SimdAlign
impl UnwindSafe for SimdAlign
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/enum.SimdAlign.html