pub unsafe fn simd_expose_provenance<T, U>(ptr: T) -> U
core_intrinsics)
Exposes a vector of pointers as a vector of addresses.
T must be a vector of pointers.
U must be a vector of usize with the same length as T.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_expose_provenance.html