pub const unsafe fn simd_funnel_shr<T>(a: T, b: T, shift: T) -> T
core_intrinsics)
Funnel Shifts vector right elementwise, with UB on overflow.
Concatenates a and b elementwise (with a in the most significant half), creating a vector of the same length, but with each element being twice as wide. Then shift this vector right elementwise by shift, shifting in zeros, and extract the least significant half of each of the elements. If a and b are the same, this is equivalent to an elementwise rotate right operation.
T must be a vector of integers.
Each element of shift must be less than <int>::BITS.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_funnel_shr.html