pub unsafe fn simd_insert_dyn<T, U>(x: T, idx: u32, val: U) -> T
core_intrinsics)
Inserts an element into a vector, returning the updated vector.
T must be a vector with element type U.
If the index is const, simd_insert may emit better assembly.
idx must be in-bounds of the vector.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_insert_dyn.html