pub const unsafe fn simd_neg<T>(x: T) -> T
core_intrinsics)
Negates a vector elementwise.
T must be a vector of integers or floats.
Rust panics for -<int>::Min due to overflow, but it is not UB with this intrinsic.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_neg.html