W3cubDocs

/Rust

Function simd_reduce_add_ordered

pub const unsafe fn simd_reduce_add_ordered<T, U>(x: T, y: U) -> U
🔬This is a nightly-only experimental API. (core_intrinsics)

Adds elements within a vector from left to right.

T must be a vector of integers or floats.

U must be the element type of T.

Starting with the value y, add the elements of x and accumulate.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_reduce_add_ordered.html