pub const unsafe fn simd_shl<T>(lhs: T, rhs: T) -> T
core_intrinsics)
Shifts vector left elementwise, with UB on overflow.
Shifts lhs left by rhs, shifting in sign bits for signed types.
T must be a vector of integers.
Each element of rhs must be less than <int>::BITS.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_shl.html