pub const unsafe fn simd_shr<T>(lhs: T, rhs: T) -> T
core_intrinsics)
Shifts vector right elementwise, with UB on overflow.
T must be a vector of integers.
Shifts lhs right by rhs, shifting in sign bits for signed types.
Each element of rhs must be less than <int>::BITS.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_shr.html