pub const unsafe fn simd_with_exposed_provenance<T, U>(addr: T) -> U
core_intrinsics)
Creates a vector of pointers from a vector of addresses.
T must be a vector of usize.
U must be a vector of pointers, with the same length as T.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/simd/fn.simd_with_exposed_provenance.html