Struct Repeat

struct Repeat { ... }

A reader which yields one byte over and over and over and over and over and...

This struct is generally created by calling [repeat()]. Please see the documentation of [repeat()] for more details.

Implementations

impl Debug for Repeat

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Repeat

impl Read for Repeat

fn read(self: &mut Self, buf: &mut [u8]) -> Result<usize>
fn read_exact(self: &mut Self, buf: &mut [u8]) -> Result<()>
fn read_buf(self: &mut Self, buf: BorrowedCursor<'_>) -> Result<()>
fn read_buf_exact(self: &mut Self, buf: BorrowedCursor<'_>) -> Result<()>
fn read_to_end(self: &mut Self, _: &mut Vec<u8>) -> Result<usize>

This function is not supported by io::Repeat, because there's no end of its data

fn read_to_string(self: &mut Self, _: &mut String) -> Result<usize>

This function is not supported by io::Repeat, because there's no end of its data

fn read_vectored(self: &mut Self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
fn is_read_vectored(self: &Self) -> bool

impl RefUnwindSafe for Repeat

impl Send for Repeat

impl Sync for Repeat

impl Unpin for Repeat

impl UnsafeUnpin for Repeat

impl UnwindSafe for Repeat

impl<T> Any for Repeat

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Repeat

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Repeat

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Repeat

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Repeat

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Repeat

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Repeat

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>