pub struct BorrowedCursor<'a> { /* private fields */ }
core_io_borrowed_buf #117693)
A writeable view of the unfilled portion of a BorrowedBuf.
The unfilled portion consists of an initialized and an uninitialized part; see BorrowedBuf for details.
Data can be written directly to the cursor by using append or indirectly by getting a slice of part or all of the cursor and writing into the slice. In the indirect case, the caller must call advance after writing to inform the cursor how many bytes have been written.
Once data is written to the cursor, it becomes part of the filled portion of the underlying BorrowedBuf and can no longer be accessed or re-written by the cursor. I.e., the cursor tracks the unfilled part of the underlying BorrowedBuf.
The lifetime 'a is a bound on the lifetime of the underlying buffer (which means it is a bound on the data in that buffer by transitivity).
impl<'a> BorrowedCursor<'a>
pub fn reborrow<'this>(&'this mut self) -> BorrowedCursor<'this> ⓘ
core_io_borrowed_buf #117693)
Reborrows this cursor by cloning it with a smaller lifetime.
Since a cursor maintains unique access to its underlying buffer, the borrowed cursor is not accessible while the new cursor exists.
pub fn capacity(&self) -> usize
core_io_borrowed_buf #117693)
Returns the available space in the cursor.
pub fn written(&self) -> usize
core_io_borrowed_buf #117693)
Returns the number of bytes written to the BorrowedBuf this cursor was created from.
In particular, the count returned is shared by all reborrows of the cursor.
pub fn init_mut(&mut self) -> &mut [u8] ⓘ
core_io_borrowed_buf #117693)
Returns a mutable reference to the initialized portion of the cursor.
pub unsafe fn as_mut(&mut self) -> &mut [MaybeUninit<u8>]
core_io_borrowed_buf #117693)
Returns a mutable reference to the whole cursor.
The caller must not uninitialize any bytes in the initialized portion of the cursor.
pub fn advance(&mut self, n: usize) -> &mut BorrowedCursor<'a> ⓘ
core_io_borrowed_buf #117693)
Advances the cursor by asserting that n bytes have been filled.
After advancing, the n bytes are no longer accessible via the cursor and can only be accessed via the underlying buffer. I.e., the buffer’s filled portion grows by n elements and its unfilled portion (and the capacity of this cursor) shrinks by n elements.
If less than n bytes initialized (by the cursor’s point of view), set_init should be called first.
Panics if there are less than n bytes initialized.
pub unsafe fn advance_unchecked(&mut self, n: usize) -> &mut BorrowedCursor<'a> ⓘ
core_io_borrowed_buf #117693)
Advances the cursor by asserting that n bytes have been filled.
After advancing, the n bytes are no longer accessible via the cursor and can only be accessed via the underlying buffer. I.e., the buffer’s filled portion grows by n elements and its unfilled portion (and the capacity of this cursor) shrinks by n elements.
The caller must ensure that the first n bytes of the cursor have been properly initialised.
pub fn ensure_init(&mut self) -> &mut BorrowedCursor<'a> ⓘ
core_io_borrowed_buf #117693)
Initializes all bytes in the cursor.
pub unsafe fn set_init(&mut self, n: usize) -> &mut BorrowedCursor<'a> ⓘ
core_io_borrowed_buf #117693)
Asserts that the first n unfilled bytes of the cursor are initialized.
BorrowedBuf assumes that bytes are never de-initialized, so this method does nothing when called with fewer bytes than are already known to be initialized.
The caller must ensure that the first n bytes of the buffer have already been initialized.
pub fn append(&mut self, buf: &[u8])
core_io_borrowed_buf #117693)
Appends data to the cursor, advancing position within its buffer.
Panics if self.capacity() is less than buf.len().
pub fn with_unfilled_buf<T>(
&mut self,
f: impl FnOnce(&mut BorrowedBuf<'_>) -> T,
) -> Tcore_io_borrowed_buf #117693)
Runs the given closure with a BorrowedBuf containing the unfilled part of the cursor.
This enables inspecting what was written to the cursor.
Panics if the BorrowedBuf given to the closure is replaced by another one.
impl<'a> Debug for BorrowedCursor<'a>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
impl<'data> From<BorrowedCursor<'data>> for BorrowedBuf<'data>Creates a new BorrowedBuf from a cursor.
Use BorrowedCursor::with_unfilled_buf instead for a safer alternative.
fn from(buf: BorrowedCursor<'data>) -> BorrowedBuf<'data>
impl<'a> Write for BorrowedCursor<'a>
fn write(&mut self, buf: &[u8]) -> Result<usize>
fn write_vectored(&mut self, bufs: &[IoSlice<'_>]) -> Result<usize>
fn is_write_vectored(&self) -> bool
can_vector #69941)
fn write_all(&mut self, buf: &[u8]) -> Result<()>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<()>
write_all_vectored #70436)
fn flush(&mut self) -> Result<()>
fn write_fmt(&mut self, args: Arguments<'_>) -> Result<()>
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,Write. Read more
impl<'a> Freeze for BorrowedCursor<'a>
impl<'a> RefUnwindSafe for BorrowedCursor<'a>
impl<'a> Send for BorrowedCursor<'a>
impl<'a> Sync for BorrowedCursor<'a>
impl<'a> Unpin for BorrowedCursor<'a>
impl<'a> !UnwindSafe for BorrowedCursor<'a>
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/io/struct.BorrowedCursor.html