pub struct Peekable<I>where
I: Iterator,{ /* private fields */ }
An iterator with a peek() that returns an optional reference to the next element.
This struct is created by the peekable method on Iterator. See its documentation for more.
impl<I> Peekable<I>where
I: Iterator,pub fn peek(&mut self) -> Option<&<I as Iterator>::Item>
Returns a reference to the next() value without advancing the iterator.
Like next, if there is a value, it is wrapped in a Some(T). But if the iteration is over, None is returned.
Because peek() returns a reference, and many iterators iterate over references, there can be a possibly confusing situation where the return value is a double reference. You can see this effect in the examples below.
Basic usage:
let xs = [1, 2, 3]; let mut iter = xs.iter().peekable(); // peek() lets us see into the future assert_eq!(iter.peek(), Some(&&1)); assert_eq!(iter.next(), Some(&1)); assert_eq!(iter.next(), Some(&2)); // The iterator does not advance even if we `peek` multiple times assert_eq!(iter.peek(), Some(&&3)); assert_eq!(iter.peek(), Some(&&3)); assert_eq!(iter.next(), Some(&3)); // After the iterator is finished, so is `peek()` assert_eq!(iter.peek(), None); assert_eq!(iter.next(), None);
pub fn peek_mut(&mut self) -> Option<&mut <I as Iterator>::Item>
Returns a mutable reference to the next() value without advancing the iterator.
Like next, if there is a value, it is wrapped in a Some(T). But if the iteration is over, None is returned.
Because peek_mut() returns a reference, and many iterators iterate over references, there can be a possibly confusing situation where the return value is a double reference. You can see this effect in the examples below.
Basic usage:
let mut iter = [1, 2, 3].iter().peekable();
// Like with `peek()`, we can see into the future without advancing the iterator.
assert_eq!(iter.peek_mut(), Some(&mut &1));
assert_eq!(iter.peek_mut(), Some(&mut &1));
assert_eq!(iter.next(), Some(&1));
// Peek into the iterator and set the value behind the mutable reference.
if let Some(p) = iter.peek_mut() {
assert_eq!(*p, &2);
*p = &5;
}
// The value we put in reappears as the iterator continues.
assert_eq!(iter.collect::<Vec<_>>(), vec![&5, &3]);pub fn next_if(
&mut self,
func: impl FnOnce(&<I as Iterator>::Item) -> bool,
) -> Option<<I as Iterator>::Item>Consume and return the next value of this iterator if a condition is true.
If func returns true for the next value of this iterator, consume and return it. Otherwise, return None.
Consume a number if it’s equal to 0.
let mut iter = (0..5).peekable(); // The first item of the iterator is 0; consume it. assert_eq!(iter.next_if(|&x| x == 0), Some(0)); // The next item returned is now 1, so `next_if` will return `None`. assert_eq!(iter.next_if(|&x| x == 0), None); // `next_if` retains the next item if the predicate evaluates to `false` for it. assert_eq!(iter.next(), Some(1));
Consume any number less than 10.
let mut iter = (1..20).peekable();
// Consume all numbers less than 10
while iter.next_if(|&x| x < 10).is_some() {}
// The next value returned will be 10
assert_eq!(iter.next(), Some(10));pub fn next_if_eq<T>(&mut self, expected: &T) -> Option<<I as Iterator>::Item>where
<I as Iterator>::Item: PartialEq<T>,
T: ?Sized,Consume and return the next item if it is equal to expected.
Consume a number if it’s equal to 0.
let mut iter = (0..5).peekable(); // The first item of the iterator is 0; consume it. assert_eq!(iter.next_if_eq(&0), Some(0)); // The next item returned is now 1, so `next_if_eq` will return `None`. assert_eq!(iter.next_if_eq(&0), None); // `next_if_eq` retains the next item if it was not equal to `expected`. assert_eq!(iter.next(), Some(1));
pub fn next_if_map<R>(
&mut self,
f: impl FnOnce(<I as Iterator>::Item) -> Result<R, <I as Iterator>::Item>,
) -> Option<R>peekable_next_if_map #143702)
Consumes the next value of this iterator and applies a function f on it, returning the result if the closure returns Ok.
Otherwise if the closure returns Err the value is put back for the next iteration.
The content of the Err variant is typically the original value of the closure, but this is not required. If a different value is returned, the next peek() or next() call will result in this new value. This is similar to modifying the output of peek_mut().
If the closure panics, the next value will always be consumed and dropped even if the panic is caught, because the closure never returned an Err value to put back.
See also: next_if_map_mut.
Parse the leading decimal number from an iterator of characters.
#![feature(peekable_next_if_map)]
let mut iter = "125 GOTO 10".chars().peekable();
let mut line_num = 0_u32;
while let Some(digit) = iter.next_if_map(|c| c.to_digit(10).ok_or(c)) {
line_num = line_num * 10 + digit;
}
assert_eq!(line_num, 125);
assert_eq!(iter.collect::<String>(), " GOTO 10");Matching custom types.
#![feature(peekable_next_if_map)]
#[derive(Debug, PartialEq, Eq)]
enum Node {
Comment(String),
Red(String),
Green(String),
Blue(String),
}
/// Combines all consecutive `Comment` nodes into a single one.
fn combine_comments(nodes: Vec<Node>) -> Vec<Node> {
let mut result = Vec::with_capacity(nodes.len());
let mut iter = nodes.into_iter().peekable();
let mut comment_text = None::<String>;
loop {
// Typically the closure in .next_if_map() matches on the input,
// extracts the desired pattern into an `Ok`,
// and puts the rest into an `Err`.
while let Some(text) = iter.next_if_map(|node| match node {
Node::Comment(text) => Ok(text),
other => Err(other),
}) {
comment_text.get_or_insert_default().push_str(&text);
}
if let Some(text) = comment_text.take() {
result.push(Node::Comment(text));
}
if let Some(node) = iter.next() {
result.push(node);
} else {
break;
}
}
result
}pub fn next_if_map_mut<R>(
&mut self,
f: impl FnOnce(&mut <I as Iterator>::Item) -> Option<R>,
) -> Option<R>peekable_next_if_map #143702)
Gives a mutable reference to the next value of the iterator and applies a function f to it, returning the result and advancing the iterator if f returns Some.
Otherwise, if f returns None, the next value is kept for the next iteration.
If f panics, the item that is consumed from the iterator as if Some was returned from f. The value will be dropped.
This is similar to next_if_map, except ownership of the item is not given to f. This can be preferable if f would copy the item anyway.
Parse the leading decimal number from an iterator of characters.
#![feature(peekable_next_if_map)]
let mut iter = "125 GOTO 10".chars().peekable();
let mut line_num = 0_u32;
while let Some(digit) = iter.next_if_map_mut(|c| c.to_digit(10)) {
line_num = line_num * 10 + digit;
}
assert_eq!(line_num, 125);
assert_eq!(iter.collect::<String>(), " GOTO 10");impl<I> Clone for Peekable<I>where
I: Clone + Iterator,
<I as Iterator>::Item: Clone,fn clone(&self) -> Peekable<I> ⓘ
fn clone_from(&mut self, source: &Self)
source. Read more
impl<I> Debug for Peekable<I>where
I: Debug + Iterator,
<I as Iterator>::Item: Debug,fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
impl<I> DoubleEndedIterator for Peekable<I>where
I: DoubleEndedIterator,fn next_back(&mut self) -> Option<<Peekable<I> as Iterator>::Item>
fn try_rfold<B, F, R>(&mut self, init: B, f: F) -> Rwhere
Peekable<I>: Sized,
F: FnMut(B, <Peekable<I> as Iterator>::Item) -> R,
R: Try<Output = B>,Iterator::try_fold(): it takes elements starting from the back of the iterator. Read more
fn rfold<Acc, Fold>(self, init: Acc, fold: Fold) -> Accwhere
Fold: FnMut(Acc, <Peekable<I> as Iterator>::Item) -> Acc,fn advance_back_by(&mut self, n: usize) -> Result<(), NonZero<usize>>
iter_advance_by #77404)
n elements. Read more
fn nth_back(&mut self, n: usize) -> Option<Self::Item>
nth element from the end of the iterator. Read more
fn rfind<P>(&mut self, predicate: P) -> Option<Self::Item>where
Self: Sized,
P: FnMut(&Self::Item) -> bool,impl<I> ExactSizeIterator for Peekable<I>where
I: ExactSizeIterator,fn len(&self) -> usize
fn is_empty(&self) -> bool
exact_size_is_empty #35428)
true if the iterator is empty. Read more
impl<I> Iterator for Peekable<I>where
I: Iterator,type Item = <I as Iterator>::Item
fn next(&mut self) -> Option<<I as Iterator>::Item>
fn count(self) -> usize
fn nth(&mut self, n: usize) -> Option<<I as Iterator>::Item>
nth element of the iterator. Read more
fn last(self) -> Option<<I as Iterator>::Item>
fn size_hint(&self) -> (usize, Option<usize>)
fn try_fold<B, F, R>(&mut self, init: B, f: F) -> Rwhere
Peekable<I>: Sized,
F: FnMut(B, <Peekable<I> as Iterator>::Item) -> R,
R: Try<Output = B>,fn fold<Acc, Fold>(self, init: Acc, fold: Fold) -> Accwhere
Fold: FnMut(Acc, <Peekable<I> as Iterator>::Item) -> Acc,fn next_chunk<const N: usize>(
&mut self,
) -> Result<[Self::Item; N], IntoIter<Self::Item, N>>where
Self: Sized,iter_next_chunk #98326)
N values. Read more
fn advance_by(&mut self, n: usize) -> Result<(), NonZero<usize>>
iter_advance_by #77404)
n elements. Read more
fn step_by(self, step: usize) -> StepBy<Self> ⓘwhere
Self: Sized,fn chain<U>(self, other: U) -> Chain<Self, <U as IntoIterator>::IntoIter> ⓘwhere
Self: Sized,
U: IntoIterator<Item = Self::Item>,fn zip<U>(self, other: U) -> Zip<Self, <U as IntoIterator>::IntoIter> ⓘwhere
Self: Sized,
U: IntoIterator,fn intersperse(self, separator: Self::Item) -> Intersperse<Self> ⓘwhere
Self: Sized,
Self::Item: Clone,iter_intersperse #79524)
separator between adjacent items of the original iterator. Read more
fn intersperse_with<G>(self, separator: G) -> IntersperseWith<Self, G> ⓘwhere
Self: Sized,
G: FnMut() -> Self::Item,iter_intersperse #79524)
separator between adjacent items of the original iterator. Read more
fn map<B, F>(self, f: F) -> Map<Self, F> ⓘwhere
Self: Sized,
F: FnMut(Self::Item) -> B,fn for_each<F>(self, f: F)where
Self: Sized,
F: FnMut(Self::Item),fn filter<P>(self, predicate: P) -> Filter<Self, P> ⓘwhere
Self: Sized,
P: FnMut(&Self::Item) -> bool,fn filter_map<B, F>(self, f: F) -> FilterMap<Self, F> ⓘwhere
Self: Sized,
F: FnMut(Self::Item) -> Option<B>,fn enumerate(self) -> Enumerate<Self> ⓘwhere
Self: Sized,fn peekable(self) -> Peekable<Self> ⓘwhere
Self: Sized,peek and peek_mut methods to look at the next element of the iterator without consuming it. See their documentation for more information. Read more
fn skip_while<P>(self, predicate: P) -> SkipWhile<Self, P> ⓘwhere
Self: Sized,
P: FnMut(&Self::Item) -> bool,fn take_while<P>(self, predicate: P) -> TakeWhile<Self, P> ⓘwhere
Self: Sized,
P: FnMut(&Self::Item) -> bool,fn map_while<B, P>(self, predicate: P) -> MapWhile<Self, P> ⓘwhere
Self: Sized,
P: FnMut(Self::Item) -> Option<B>,fn skip(self, n: usize) -> Skip<Self> ⓘwhere
Self: Sized,n elements. Read more
fn take(self, n: usize) -> Take<Self> ⓘwhere
Self: Sized,n elements, or fewer if the underlying iterator ends sooner. Read more
fn scan<St, B, F>(self, initial_state: St, f: F) -> Scan<Self, St, F> ⓘwhere
Self: Sized,
F: FnMut(&mut St, Self::Item) -> Option<B>,fold, holds internal state, but unlike fold, produces a new iterator. Read more
fn flat_map<U, F>(self, f: F) -> FlatMap<Self, U, F> ⓘwhere
Self: Sized,
U: IntoIterator,
F: FnMut(Self::Item) -> U,fn flatten(self) -> Flatten<Self> ⓘwhere
Self: Sized,
Self::Item: IntoIterator,fn map_windows<F, R, const N: usize>(self, f: F) -> MapWindows<Self, F, N> ⓘwhere
Self: Sized,
F: FnMut(&[Self::Item; N]) -> R,iter_map_windows #87155)
f for each contiguous window of size N over self and returns an iterator over the outputs of f. Like slice::windows(), the windows during mapping overlap as well. Read more
fn fuse(self) -> Fuse<Self> ⓘwhere
Self: Sized,fn inspect<F>(self, f: F) -> Inspect<Self, F> ⓘwhere
Self: Sized,
F: FnMut(&Self::Item),fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,Iterator. Read more
fn collect<B>(self) -> Bwhere
B: FromIterator<Self::Item>,
Self: Sized,fn try_collect<B>(
&mut self,
) -> <<Self::Item as Try>::Residual as Residual<B>>::TryTypewhere
Self: Sized,
Self::Item: Try,
<Self::Item as Try>::Residual: Residual<B>,
B: FromIterator<<Self::Item as Try>::Output>,iterator_try_collect #94047)
fn collect_into<E>(self, collection: &mut E) -> &mut Ewhere
E: Extend<Self::Item>,
Self: Sized,iter_collect_into #94780)
fn partition<B, F>(self, f: F) -> (B, B)where
Self: Sized,
B: Default + Extend<Self::Item>,
F: FnMut(&Self::Item) -> bool,fn partition_in_place<'a, T, P>(self, predicate: P) -> usizewhere
T: 'a,
Self: Sized + DoubleEndedIterator<Item = &'a mut T>,
P: FnMut(&T) -> bool,iter_partition_in_place #62543)
true precede all those that return false. Returns the number of true elements found. Read more
fn is_partitioned<P>(self, predicate: P) -> boolwhere
Self: Sized,
P: FnMut(Self::Item) -> bool,iter_is_partitioned #62544)
true precede all those that return false. Read more
fn try_for_each<F, R>(&mut self, f: F) -> Rwhere
Self: Sized,
F: FnMut(Self::Item) -> R,
R: Try<Output = ()>,fn reduce<F>(self, f: F) -> Option<Self::Item>where
Self: Sized,
F: FnMut(Self::Item, Self::Item) -> Self::Item,fn try_reduce<R>(
&mut self,
f: impl FnMut(Self::Item, Self::Item) -> R,
) -> <<R as Try>::Residual as Residual<Option<<R as Try>::Output>>>::TryTypewhere
Self: Sized,
R: Try<Output = Self::Item>,
<R as Try>::Residual: Residual<Option<Self::Item>>,iterator_try_reduce #87053)
fn all<F>(&mut self, f: F) -> boolwhere
Self: Sized,
F: FnMut(Self::Item) -> bool,fn any<F>(&mut self, f: F) -> boolwhere
Self: Sized,
F: FnMut(Self::Item) -> bool,fn find<P>(&mut self, predicate: P) -> Option<Self::Item>where
Self: Sized,
P: FnMut(&Self::Item) -> bool,fn find_map<B, F>(&mut self, f: F) -> Option<B>where
Self: Sized,
F: FnMut(Self::Item) -> Option<B>,fn try_find<R>(
&mut self,
f: impl FnMut(&Self::Item) -> R,
) -> <<R as Try>::Residual as Residual<Option<Self::Item>>>::TryTypewhere
Self: Sized,
R: Try<Output = bool>,
<R as Try>::Residual: Residual<Option<Self::Item>>,try_find #63178)
fn position<P>(&mut self, predicate: P) -> Option<usize>where
Self: Sized,
P: FnMut(Self::Item) -> bool,fn rposition<P>(&mut self, predicate: P) -> Option<usize>where
P: FnMut(Self::Item) -> bool,
Self: Sized + ExactSizeIterator + DoubleEndedIterator,fn max(self) -> Option<Self::Item>where
Self: Sized,
Self::Item: Ord,fn min(self) -> Option<Self::Item>where
Self: Sized,
Self::Item: Ord,fn max_by_key<B, F>(self, f: F) -> Option<Self::Item>where
B: Ord,
Self: Sized,
F: FnMut(&Self::Item) -> B,fn max_by<F>(self, compare: F) -> Option<Self::Item>where
Self: Sized,
F: FnMut(&Self::Item, &Self::Item) -> Ordering,fn min_by_key<B, F>(self, f: F) -> Option<Self::Item>where
B: Ord,
Self: Sized,
F: FnMut(&Self::Item) -> B,fn min_by<F>(self, compare: F) -> Option<Self::Item>where
Self: Sized,
F: FnMut(&Self::Item, &Self::Item) -> Ordering,fn rev(self) -> Rev<Self> ⓘwhere
Self: Sized + DoubleEndedIterator,fn unzip<A, B, FromA, FromB>(self) -> (FromA, FromB)where
FromA: Default + Extend<A>,
FromB: Default + Extend<B>,
Self: Sized + Iterator<Item = (A, B)>,fn copied<'a, T>(self) -> Copied<Self> ⓘwhere
T: Copy + 'a,
Self: Sized + Iterator<Item = &'a T>,fn cloned<'a, T>(self) -> Cloned<Self> ⓘwhere
T: Clone + 'a,
Self: Sized + Iterator<Item = &'a T>,fn cycle(self) -> Cycle<Self> ⓘwhere
Self: Sized + Clone,fn array_chunks<const N: usize>(self) -> ArrayChunks<Self, N> ⓘwhere
Self: Sized,iter_array_chunks #100450)
N elements of the iterator at a time. Read more
fn sum<S>(self) -> Swhere
Self: Sized,
S: Sum<Self::Item>,fn product<P>(self) -> Pwhere
Self: Sized,
P: Product<Self::Item>,fn cmp<I>(self, other: I) -> Orderingwhere
I: IntoIterator<Item = Self::Item>,
Self::Item: Ord,
Self: Sized,fn cmp_by<I, F>(self, other: I, cmp: F) -> Orderingwhere
Self: Sized,
I: IntoIterator,
F: FnMut(Self::Item, <I as IntoIterator>::Item) -> Ordering,iter_order_by #64295)
Iterator with those of another with respect to the specified comparison function. Read more
fn partial_cmp<I>(self, other: I) -> Option<Ordering>where
I: IntoIterator,
Self::Item: PartialOrd<<I as IntoIterator>::Item>,
Self: Sized,PartialOrd elements of this Iterator with those of another. The comparison works like short-circuit evaluation, returning a result without comparing the remaining elements. As soon as an order can be determined, the evaluation stops and a result is returned. Read more
fn partial_cmp_by<I, F>(self, other: I, partial_cmp: F) -> Option<Ordering>where
Self: Sized,
I: IntoIterator,
F: FnMut(Self::Item, <I as IntoIterator>::Item) -> Option<Ordering>,iter_order_by #64295)
Iterator with those of another with respect to the specified comparison function. Read more
fn eq<I>(self, other: I) -> boolwhere
I: IntoIterator,
Self::Item: PartialEq<<I as IntoIterator>::Item>,
Self: Sized,fn eq_by<I, F>(self, other: I, eq: F) -> boolwhere
Self: Sized,
I: IntoIterator,
F: FnMut(Self::Item, <I as IntoIterator>::Item) -> bool,iter_order_by #64295)
Iterator are equal to those of another with respect to the specified equality function. Read more
fn ne<I>(self, other: I) -> boolwhere
I: IntoIterator,
Self::Item: PartialEq<<I as IntoIterator>::Item>,
Self: Sized,fn lt<I>(self, other: I) -> boolwhere
I: IntoIterator,
Self::Item: PartialOrd<<I as IntoIterator>::Item>,
Self: Sized,Iterator are lexicographically less than those of another. Read more
fn le<I>(self, other: I) -> boolwhere
I: IntoIterator,
Self::Item: PartialOrd<<I as IntoIterator>::Item>,
Self: Sized,Iterator are lexicographically less or equal to those of another. Read more
fn gt<I>(self, other: I) -> boolwhere
I: IntoIterator,
Self::Item: PartialOrd<<I as IntoIterator>::Item>,
Self: Sized,Iterator are lexicographically greater than those of another. Read more
fn ge<I>(self, other: I) -> boolwhere
I: IntoIterator,
Self::Item: PartialOrd<<I as IntoIterator>::Item>,
Self: Sized,Iterator are lexicographically greater than or equal to those of another. Read more
fn is_sorted(self) -> boolwhere
Self: Sized,
Self::Item: PartialOrd,fn is_sorted_by<F>(self, compare: F) -> boolwhere
Self: Sized,
F: FnMut(&Self::Item, &Self::Item) -> bool,fn is_sorted_by_key<F, K>(self, f: F) -> boolwhere
Self: Sized,
F: FnMut(Self::Item) -> K,
K: PartialOrd,impl<I> FusedIterator for Peekable<I>where
I: FusedIterator,impl<I> TrustedLen for Peekable<I>where
I: TrustedLen,impl<I> Freeze for Peekable<I>where
I: Freeze,
<I as Iterator>::Item: Freeze,impl<I> RefUnwindSafe for Peekable<I>where
I: RefUnwindSafe,
<I as Iterator>::Item: RefUnwindSafe,impl<I> Send for Peekable<I>where
I: Send,
<I as Iterator>::Item: Send,impl<I> Sync for Peekable<I>where
I: Sync,
<I as Iterator>::Item: Sync,impl<I> Unpin for Peekable<I>where
I: Unpin,
<I as Iterator>::Item: Unpin,impl<I> UnwindSafe for Peekable<I>where
I: UnwindSafe,
<I as Iterator>::Item: UnwindSafe,impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> CloneToUninit for Twhere
T: Clone,unsafe fn clone_to_uninit(&self, dest: *mut u8)
clone_to_uninit #126799)
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<I> IntoIterator for Iwhere
I: Iterator,type Item = <I as Iterator>::Item
type IntoIter = I
fn into_iter(self) -> I
impl<T> ToOwned for Twhere
T: Clone,type Owned = T
fn to_owned(&self) -> T
fn clone_into(&self, target: &mut T)
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/iter/struct.Peekable.html