pub enum Shutdown {
Read,
Write,
Both,
}
Possible values which can be passed to the TcpStream::shutdown method.
Read
The reading portion of the TcpStream should be shut down.
Write
The writing portion of the TcpStream should be shut down.
All currently blocked and future writes will return an error.
Both
Both the reading and the writing portions of the TcpStream should be shut down.
See Shutdown::Read and Shutdown::Write for more information.
impl Clone for Shutdown
fn clone(&self) -> Shutdown
fn clone_from(&mut self, source: &Self)
source. Read more
impl Debug for Shutdown
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl PartialEq for Shutdown
fn eq(&self, other: &Shutdown) -> bool
self and other values to be equal, and is used by ==.fn ne(&self, other: &Rhs) -> bool
!=. The default implementation is almost always sufficient, and should not be overridden without very good reason.impl Copy for Shutdown
impl Eq for Shutdown
impl StructuralPartialEq for Shutdown
impl Freeze for Shutdown
impl RefUnwindSafe for Shutdown
impl Send for Shutdown
impl Sync for Shutdown
impl Unpin for Shutdown
impl UnwindSafe for Shutdown
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> CloneToUninit for Twhere
T: Clone,unsafe fn clone_to_uninit(&self, dest: *mut u8)
clone_to_uninit #126799)
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToOwned for Twhere
T: Clone,type Owned = T
fn to_owned(&self) -> T
fn clone_into(&self, target: &mut T)
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/net/enum.Shutdown.html