Struct Incoming
struct Incoming<'a> { ... }
An iterator that infinitely accepts connections on a TcpListener.
This struct is created by the TcpListener::incoming method.
See its documentation for more.
Implementations
impl FusedIterator for Incoming<'_>
impl<'a> Debug for Incoming<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for Incoming<'a>
impl<'a> Iterator for Incoming<'a>
fn next(self: &mut Self) -> Option<Result<TcpStream>>
impl<'a> RefUnwindSafe for Incoming<'a>
impl<'a> Send for Incoming<'a>
impl<'a> Sync for Incoming<'a>
impl<'a> Unpin for Incoming<'a>
impl<'a> UnsafeUnpin for Incoming<'a>
impl<'a> UnwindSafe for Incoming<'a>
impl<I> IntoIterator for Incoming<'a>
fn into_iter(self: Self) -> I
impl<T> Any for Incoming<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Incoming<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Incoming<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Incoming<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Incoming<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Incoming<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Incoming<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>