pub type NonZeroI16 = NonZero<i16>;
An i16 that is known not to equal zero.
This enables some memory layout optimization. For example, Option<NonZeroI16> is the same size as i16:
assert_eq!(size_of::<Option<core::num::NonZeroI16>>(), size_of::<i16>());
NonZeroI16 is guaranteed to have the same layout and bit validity as i16 with the exception that 0 is not a valid instance. Option<NonZeroI16> is guaranteed to be compatible with i16, including in FFI.
Thanks to the null pointer optimization, NonZeroI16 and Option<NonZeroI16> are guaranteed to have the same size and alignment:
use std::num::NonZeroI16; assert_eq!(size_of::<NonZeroI16>(), size_of::<Option<NonZeroI16>>()); assert_eq!(align_of::<NonZeroI16>(), align_of::<Option<NonZeroI16>>());
Since both Option::unwrap() and Option::expect() are const, it is possible to define a new NonZeroI16 at compile time via:
use std::num::NonZeroI16;
const TEN: NonZeroI16 = NonZeroI16::new(10).expect("ten is non-zero");pub struct NonZeroI16(/* private fields */);
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/num/type.NonZeroI16.html