pub trait IntoRawFd {
// Required method
fn into_raw_fd(self) -> RawFd;
}
target_os=trusty or WASI or target_os=motor only.A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.
fn into_raw_fd(self) -> RawFd
Consumes this object, returning the raw underlying file descriptor.
This function is typically used to transfer ownership of the underlying file descriptor to the caller. When used in this way, callers are then the unique owners of the file descriptor and must close it once it’s no longer needed.
However, transferring ownership is not strictly required. Use a Into<OwnedFd>::into implementation for an API which strictly transfers ownership.
use std::fs::File;
#[cfg(any(unix, target_os = "wasi"))]
use std::os::fd::{IntoRawFd, RawFd};
let f = File::open("foo.txt")?;
#[cfg(any(unix, target_os = "wasi"))]
let raw_fd: RawFd = f.into_raw_fd();impl IntoRawFd for FileAvailable on non-target_os=trusty only.
impl IntoRawFd for PipeReaderAvailable on non-target_os=trusty only.
impl IntoRawFd for PipeWriterAvailable on non-target_os=trusty only.
impl IntoRawFd for TcpListenerAvailable on non-target_os=trusty only.
impl IntoRawFd for TcpStreamAvailable on non-target_os=trusty only.
impl IntoRawFd for UdpSocketAvailable on non-target_os=trusty only.
impl IntoRawFd for ChildStderrAvailable on Unix only.
impl IntoRawFd for ChildStdinAvailable on Unix only.
impl IntoRawFd for ChildStdoutAvailable on Unix only.
impl IntoRawFd for PidFdAvailable on Linux only.
impl IntoRawFd for UnixDatagramAvailable on Unix only.
impl IntoRawFd for UnixListenerAvailable on Unix only.
impl IntoRawFd for UnixStreamAvailable on Unix only.
impl IntoRawFd for OwnedFd
impl IntoRawFd for RawFd
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/os/fd/trait.IntoRawFd.html