👎Deprecated since 1.8.0:
these type aliases are no longer supported by the standard library, the libc crate on crates.io should be used instead for the correct definitions
Linux-specific raw type definitions.
Structs
- stat
Deprecated