Trait IntoRawFd
trait IntoRawFd
A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.
Required Methods
fn into_raw_fd(self: Self) -> RawFdConsumes this object, returning the raw underlying file descriptor.
This function is typically used to transfer ownership of the underlying file descriptor to the caller. When used in this way, callers are then the unique owners of the file descriptor and must close it once it's no longer needed.
However, transferring ownership is not strictly required. Use a [
Into<OwnedFd>::into] implementation for an API which strictly transfers ownership.Example
use std::fs::File; # use std::io; #[cfg(any(unix, target_os = "wasi"))] use std::os::fd::{IntoRawFd, RawFd}; let f = File::open("foo.txt")?; #[cfg(any(unix, target_os = "wasi"))] let raw_fd: RawFd = f.into_raw_fd(); # Ok::<(), io::Error>(())
Implementors
impl IntoRawFd for ChildStdoutimpl IntoRawFd for TcpListenerimpl IntoRawFd for UnixStreamimpl IntoRawFd for RawFdimpl IntoRawFd for UnixListenerimpl IntoRawFd for Dirimpl IntoRawFd for UdpSocketimpl IntoRawFd for Fileimpl IntoRawFd for ChildStdinimpl IntoRawFd for PipeWriterimpl IntoRawFd for TcpStreamimpl IntoRawFd for ChildStderrimpl IntoRawFd for UnixDatagramimpl IntoRawFd for PidFdimpl IntoRawFd for PipeReaderimpl IntoRawFd for OwnedFd