Trait AsRawHandle
trait AsRawHandle
Extracts raw handles.
Required Methods
fn as_raw_handle(self: &Self) -> RawHandleExtracts the raw handle.
This function is typically used to borrow an owned handle. When used in this way, this method does not pass ownership of the raw handle to the caller, and the handle is only guaranteed to be valid while the original object has not yet been destroyed.
This function may return null, such as when called on
Stdin,Stdout, orStderrwhen the console is detached.However, borrowing is not strictly required. See
AsHandle::as_handlefor an API which strictly borrows a handle.
Implementors
impl<'a> AsRawHandle for StdoutLock<'a>impl AsRawHandle for Stdinimpl AsRawHandle for Childimpl AsRawHandle for Fileimpl AsRawHandle for ChildStderrimpl AsRawHandle for Stdoutimpl<T> AsRawHandle for JoinHandle<T>impl AsRawHandle for BorrowedHandle<'_>impl<'a> AsRawHandle for StdinLock<'a>impl<'a> AsRawHandle for StderrLock<'a>impl AsRawHandle for ChildStdoutimpl AsRawHandle for PipeWriterimpl AsRawHandle for OwnedHandleimpl AsRawHandle for Stderrimpl AsRawHandle for PipeReaderimpl AsRawHandle for ChildStdin