Trait AsRawSocket
trait AsRawSocket
Extracts raw sockets.
Required Methods
fn as_raw_socket(self: &Self) -> RawSocketExtracts the raw socket.
This function is typically used to borrow an owned socket. When used in this way, this method does not pass ownership of the raw socket to the caller, and the socket is only guaranteed to be valid while the original object has not yet been destroyed.
However, borrowing is not strictly required. See
AsSocket::as_socketfor an API which strictly borrows a socket.
Implementors
impl AsRawSocket for UnixStreamimpl AsRawSocket for UnixListenerimpl AsRawSocket for TcpStreamimpl AsRawSocket for TcpListenerimpl AsRawSocket for OwnedSocketimpl AsRawSocket for UdpSocketimpl AsRawSocket for BorrowedSocket<'_>