Trait FromRawSocket
trait FromRawSocket
Creates I/O objects from raw sockets.
Required Methods
unsafe fn from_raw_socket(sock: RawSocket) -> SelfConstructs a new I/O object from the specified raw socket.
This function is typically used to consume ownership of the socket given, passing responsibility for closing the socket to the returned object. When used in this way, the returned object will take responsibility for closing it when the object goes out of scope.
However, consuming ownership is not strictly required. Use a
From<OwnedSocket>::fromimplementation for an API which strictly consumes ownership.Safety
The
socketpassed in must:- be an owned socket; in particular, it must be open.
- be a socket that may be freed via
closesocket.
Implementors
impl FromRawSocket for OwnedSocketimpl FromRawSocket for TcpListenerimpl FromRawSocket for TcpStreamimpl FromRawSocket for UnixStreamimpl FromRawSocket for UdpSocketimpl FromRawSocket for UnixListener