Trait IntoRawHandle
trait IntoRawHandle
A trait to express the ability to consume an object and acquire ownership of
its raw HANDLE.
Required Methods
fn into_raw_handle(self: Self) -> RawHandleConsumes this object, returning the raw underlying handle.
This function is typically used to transfer ownership of the underlying handle to the caller. When used in this way, callers are then the unique owners of the handle and must close it once it's no longer needed.
However, transferring ownership is not strictly required. Use a
Into<OwnedHandle>::intoimplementation for an API which strictly transfers ownership.
Implementors
impl IntoRawHandle for OwnedHandleimpl IntoRawHandle for PipeReaderimpl IntoRawHandle for ChildStdoutimpl<T> IntoRawHandle for JoinHandle<T>impl IntoRawHandle for ChildStdinimpl IntoRawHandle for PipeWriterimpl IntoRawHandle for Fileimpl IntoRawHandle for ChildStderrimpl IntoRawHandle for Child