#[non_exhaustive]pub struct NormalizeError;
normalize_lexically #134694)
An error returned from Path::normalize_lexically if a .. parent reference would escape the path.
impl Debug for NormalizeError
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Display for NormalizeError
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl Error for NormalizeError
fn source(&self) -> Option<&(dyn Error + 'static)>
fn description(&self) -> &str
fn cause(&self) -> Option<&dyn Error>
fn provide<'a>(&'a self, request: &mut Request<'a>)
error_generic_member_access #99301)
impl PartialEq for NormalizeError
fn eq(&self, other: &NormalizeError) -> bool
self and other values to be equal, and is used by ==.fn ne(&self, other: &Rhs) -> bool
!=. The default implementation is almost always sufficient, and should not be overridden without very good reason.impl StructuralPartialEq for NormalizeError
impl Freeze for NormalizeError
impl RefUnwindSafe for NormalizeError
impl Send for NormalizeError
impl Sync for NormalizeError
impl Unpin for NormalizeError
impl UnwindSafe for NormalizeError
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/path/struct.NormalizeError.html