pub trait SimdPartialOrd: SimdPartialEq {
// Required methods
fn simd_lt(self, other: Self) -> Self::Mask;
fn simd_le(self, other: Self) -> Self::Mask;
fn simd_gt(self, other: Self) -> Self::Mask;
fn simd_ge(self, other: Self) -> Self::Mask;
}
portable_simd #86656)
Parallel PartialOrd.
fn simd_lt(self, other: Self) -> Self::Mask
portable_simd #86656)
Test if each element is less than the corresponding element in other.
fn simd_le(self, other: Self) -> Self::Mask
portable_simd #86656)
Test if each element is less than or equal to the corresponding element in other.
fn simd_gt(self, other: Self) -> Self::Mask
portable_simd #86656)
Test if each element is greater than the corresponding element in other.
fn simd_ge(self, other: Self) -> Self::Mask
portable_simd #86656)
Test if each element is greater than or equal to the corresponding element in other.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
impl<T, const N: usize> SimdPartialOrd for Simd<*const T, N>where
LaneCount<N>: SupportedLaneCount,impl<T, const N: usize> SimdPartialOrd for Simd<*mut T, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Mask<i8, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Mask<i16, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Mask<i32, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Mask<i64, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Mask<isize, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<f32, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<f64, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<i8, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<i16, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<i32, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<i64, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<isize, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<u8, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<u16, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<u32, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<u64, N>where
LaneCount<N>: SupportedLaneCount,impl<const N: usize> SimdPartialOrd for Simd<usize, N>where
LaneCount<N>: SupportedLaneCount,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/simd/prelude/trait.SimdPartialOrd.html