pub type mask32x2 = Mask<i32, 2>;
portable_simd #86656)
A SIMD mask with two elements for vectors with 32-bit element types.
The layout of this type is unspecified, and may change between platforms and/or Rust versions, and code should not assume that it is equivalent to [i32; 2].
pub struct mask32x2(/* private fields */);
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/simd/prelude/type.mask32x2.html