Trait StdFloat
trait StdFloat: Sealed + Sized
This trait provides a possibly-temporary implementation of float functions
that may, in the absence of hardware support, canonicalize to calling an
operating system's math.h dynamically-loaded library (also known as a
shared object). As these conditionally require runtime support, they
should only appear in binaries built assuming OS support: std.
However, there is no reason SIMD types, in general, need OS support,
as for many architectures an embedded binary may simply configure that
support itself. This means these types must be visible in core
but have these functions available in std.
f32 and f64 achieve a similar trick by using "lang items", but
due to compiler limitations, it is harder to implement this approach for
abstract data types like Simd. From that need, this trait is born.
It is possible this trait will be replaced in some manner in the future,
when either the compiler or its supporting runtime functions are improved.
For now this trait is available to permit experimentation with SIMD float
operations that may lack hardware support, such as mul_add.
Required Methods
fn fract(self: Self) -> SelfReturns the floating point's fractional value, with its integer part removed.
Provided Methods
fn mul_add(self: Self, a: Self, b: Self) -> SelfElementwise fused multiply-add. Computes
(self * a) + bwith only one rounding error, yielding a more accurate result than an unfused multiply-add.Using
mul_addmay be more performant than an unfused multiply-add if the target architecture has a dedicatedfmaCPU instruction. However, this is not always true, and will be heavily dependent on designing algorithms with specific target hardware in mind.fn sqrt(self: Self) -> SelfProduces a vector where every element has the square root value of the equivalently-indexed element in
selffn sin(self: Self) -> SelfProduces a vector where every element has the sine of the value in the equivalently-indexed element in
self.fn cos(self: Self) -> SelfProduces a vector where every element has the cosine of the value in the equivalently-indexed element in
self.fn exp(self: Self) -> SelfProduces a vector where every element has the exponential (base e) of the value in the equivalently-indexed element in
self.fn exp2(self: Self) -> SelfProduces a vector where every element has the exponential (base 2) of the value in the equivalently-indexed element in
self.fn ln(self: Self) -> SelfProduces a vector where every element has the natural logarithm of the value in the equivalently-indexed element in
self.fn log(self: Self, base: Self) -> SelfProduces a vector where every element has the logarithm with respect to an arbitrary in the equivalently-indexed elements in
selfandbase.fn log2(self: Self) -> SelfProduces a vector where every element has the base-2 logarithm of the value in the equivalently-indexed element in
self.fn log10(self: Self) -> SelfProduces a vector where every element has the base-10 logarithm of the value in the equivalently-indexed element in
self.fn ceil(self: Self) -> SelfReturns the smallest integer greater than or equal to each element.
fn floor(self: Self) -> SelfReturns the largest integer value less than or equal to each element.
fn round(self: Self) -> SelfRounds to the nearest integer value. Ties round toward zero.
fn trunc(self: Self) -> SelfReturns the floating point's integer value, with its fractional part removed.