pub type mask32x32 = Mask<i32, 32>;
portable_simd #86656)
A SIMD mask with 32 elements for vectors with 32-bit element types.
The layout of this type is unspecified, and may change between platforms and/or Rust versions, and code should not assume that it is equivalent to [i32; 32].
pub struct mask32x32(/* private fields */);
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/simd/type.mask32x32.html