pub enum TryLockError<T> {
Poisoned(PoisonError<T>),
WouldBlock,
}
An enumeration of possible errors associated with a TryLockResult which can occur while trying to acquire a lock, from the try_lock method on a Mutex or the try_read and try_write methods on an RwLock.
Poisoned(PoisonError<T>)
The lock could not be acquired because another thread failed while holding the lock.
WouldBlock
The lock could not be acquired at this time because the operation would otherwise block.
impl<T> Debug for TryLockError<T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T> Display for TryLockError<T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T> Error for TryLockError<T>
fn cause(&self) -> Option<&dyn Error>
fn source(&self) -> Option<&(dyn Error + 'static)>
fn description(&self) -> &str
fn provide<'a>(&'a self, request: &mut Request<'a>)
error_generic_member_access #99301)
impl<T> From<PoisonError<T>> for TryLockError<T>
fn from(err: PoisonError<T>) -> TryLockError<T>
impl<T> Freeze for TryLockError<T>where
T: Freeze,impl<T> RefUnwindSafe for TryLockError<T>where
T: RefUnwindSafe,impl<T> Send for TryLockError<T>where
T: Send,impl<T> Sync for TryLockError<T>where
T: Sync,impl<T> Unpin for TryLockError<T>where
T: Unpin,impl<T> UnwindSafe for TryLockError<T>where
T: UnwindSafe,impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/enum.TryLockError.html