pub struct RwLock<T: ?Sized> { /* private fields */ }
nonpoison_rwlock #134645)
A reader-writer lock that does not keep track of lock poisoning.
For more information about reader-writer locks, check out the documentation for the poisoning variant of this lock (which can be found at poison::RwLock).
#![feature(nonpoison_rwlock)]
use std::sync::nonpoison::RwLock;
let lock = RwLock::new(5);
// many reader locks can be held at once
{
let r1 = lock.read();
let r2 = lock.read();
assert_eq!(*r1, 5);
assert_eq!(*r2, 5);
} // read locks are dropped at this point
// only one write lock may be held, however
{
let mut w = lock.write();
*w += 1;
assert_eq!(*w, 6);
} // write lock is dropped hereimpl<T> RwLock<T>
pub const fn new(t: T) -> RwLock<T>
nonpoison_rwlock #134645)
Creates a new instance of an RwLock<T> which is unlocked.
#![feature(nonpoison_rwlock)] use std::sync::nonpoison::RwLock; let lock = RwLock::new(5);
pub fn get_cloned(&self) -> Twhere
T: Clone,lock_value_accessors #133407)
Returns the contained value by cloning it.
#![feature(nonpoison_rwlock)] #![feature(lock_value_accessors)] use std::sync::nonpoison::RwLock; let mut lock = RwLock::new(7); assert_eq!(lock.get_cloned(), 7);
pub fn set(&self, value: T)
lock_value_accessors #133407)
Sets the contained value.
#![feature(nonpoison_rwlock)] #![feature(lock_value_accessors)] use std::sync::nonpoison::RwLock; let mut lock = RwLock::new(7); assert_eq!(lock.get_cloned(), 7); lock.set(11); assert_eq!(lock.get_cloned(), 11);
pub fn replace(&self, value: T) -> T
lock_value_accessors #133407)
Replaces the contained value with value, and returns the old contained value.
#![feature(nonpoison_rwlock)] #![feature(lock_value_accessors)] use std::sync::nonpoison::RwLock; let mut lock = RwLock::new(7); assert_eq!(lock.replace(11), 7); assert_eq!(lock.get_cloned(), 11);
impl<T: ?Sized> RwLock<T>
pub fn read(&self) -> RwLockReadGuard<'_, T>
nonpoison_rwlock #134645)
Locks this RwLock with shared read access, blocking the current thread until it can be acquired.
The calling thread will be blocked until there are no more writers which hold the lock. There may be other readers currently inside the lock when this method returns. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Returns an RAII guard which will release this threadβs shared access once it is dropped.
This function might panic when called if the lock is already held by the current thread.
#![feature(nonpoison_rwlock)]
use std::sync::Arc;
use std::sync::nonpoison::RwLock;
use std::thread;
let lock = Arc::new(RwLock::new(1));
let c_lock = Arc::clone(&lock);
let n = lock.read();
assert_eq!(*n, 1);
thread::spawn(move || {
let r = c_lock.read();
}).join().unwrap();pub fn try_read(&self) -> TryLockResult<RwLockReadGuard<'_, T>>
nonpoison_rwlock #134645)
Attempts to acquire this RwLock with shared read access.
If the access could not be granted at this time, then Err is returned. Otherwise, an RAII guard is returned which will release the shared access when it is dropped.
This function does not block.
This function does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
This function will return the WouldBlock error if the RwLock could not be acquired because it was already locked exclusively.
#![feature(nonpoison_rwlock)]
use std::sync::nonpoison::RwLock;
let lock = RwLock::new(1);
match lock.try_read() {
Ok(n) => assert_eq!(*n, 1),
Err(_) => unreachable!(),
};pub fn write(&self) -> RwLockWriteGuard<'_, T>
nonpoison_rwlock #134645)
Locks this RwLock with exclusive write access, blocking the current thread until it can be acquired.
This function will not return while other writers or other readers currently have access to the lock.
Returns an RAII guard which will drop the write access of this RwLock when dropped.
This function might panic when called if the lock is already held by the current thread.
#![feature(nonpoison_rwlock)] use std::sync::nonpoison::RwLock; let lock = RwLock::new(1); let mut n = lock.write(); *n = 2; assert!(lock.try_read().is_err());
pub fn try_write(&self) -> TryLockResult<RwLockWriteGuard<'_, T>>
nonpoison_rwlock #134645)
Attempts to lock this RwLock with exclusive write access.
If the lock could not be acquired at this time, then Err is returned. Otherwise, an RAII guard is returned which will release the lock when it is dropped.
This function does not block.
This function does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
This function will return the WouldBlock error if the RwLock could not be acquired because it was already locked.
#![feature(nonpoison_rwlock)] use std::sync::nonpoison::RwLock; let lock = RwLock::new(1); let n = lock.read(); assert_eq!(*n, 1); assert!(lock.try_write().is_err());
pub fn into_inner(self) -> Twhere
T: Sized,nonpoison_rwlock #134645)
Consumes this RwLock, returning the underlying data.
#![feature(nonpoison_rwlock)]
use std::sync::nonpoison::RwLock;
let lock = RwLock::new(String::new());
{
let mut s = lock.write();
*s = "modified".to_owned();
}
assert_eq!(lock.into_inner(), "modified");pub fn get_mut(&mut self) -> &mut T
nonpoison_rwlock #134645)
Returns a mutable reference to the underlying data.
Since this call borrows the RwLock mutably, no actual locking needs to take place β the mutable borrow statically guarantees no new locks can be acquired while this reference exists. Note that this method does not clear any previously abandoned locks (e.g., via forget() on a RwLockReadGuard or RwLockWriteGuard).
#![feature(nonpoison_rwlock)] use std::sync::nonpoison::RwLock; let mut lock = RwLock::new(0); *lock.get_mut() = 10; assert_eq!(*lock.read(), 10);
pub const fn data_ptr(&self) -> *mut T
rwlock_data_ptr #140368)
Returns a raw pointer to the underlying data.
The returned pointer is always non-null and properly aligned, but it is the userβs responsibility to ensure that any reads and writes through it are properly synchronized to avoid data races, and that it is not read or written through after the lock is dropped.
pub fn with<F, R>(&self, f: F) -> Rwhere
F: FnOnce(&T) -> R,lock_value_accessors #133407)
Locks this RwLock with shared read access to the underlying data by passing a reference to the given closure.
This method acquires the lock, calls the provided closure with a reference to the data, and returns the result of the closure. The lock is released after the closure completes, even if it panics.
#![feature(lock_value_accessors, nonpoison_rwlock)] use std::sync::nonpoison::RwLock; let rwlock = RwLock::new(2); let result = rwlock.with(|data| *data + 3); assert_eq!(result, 5);
pub fn with_mut<F, R>(&self, f: F) -> Rwhere
F: FnOnce(&mut T) -> R,lock_value_accessors #133407)
Locks this RwLock with exclusive write access to the underlying data by passing a mutable reference to the given closure.
This method acquires the lock, calls the provided closure with a mutable reference to the data, and returns the result of the closure. The lock is released after the closure completes, even if it panics.
#![feature(lock_value_accessors, nonpoison_rwlock)]
use std::sync::nonpoison::RwLock;
let rwlock = RwLock::new(2);
let result = rwlock.with_mut(|data| {
*data += 3;
*data + 5
});
assert_eq!(*rwlock.read(), 5);
assert_eq!(result, 10);impl<T: ?Sized + Debug> Debug for RwLock<T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T: Default> Default for RwLock<T>
fn default() -> RwLock<T>
Creates a new RwLock<T>, with the Default value for T.
impl<T> From<T> for RwLock<T>
fn from(t: T) -> Self
Creates a new instance of an RwLock<T> which is unlocked. This is equivalent to RwLock::new.
impl<T: ?Sized + Send> Send for RwLock<T>
impl<T: ?Sized + Send + Sync> Sync for RwLock<T>
impl<T> !Freeze for RwLock<T>
impl<T> !RefUnwindSafe for RwLock<T>
impl<T> Unpin for RwLock<T>where
T: Unpin + ?Sized,impl<T> UnwindSafe for RwLock<T>where
T: UnwindSafe + ?Sized,impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<!> for T
fn from(t: !) -> T
impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
Β© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/nonpoison/struct.RwLock.html