Struct RwLock
struct RwLock<T: ?Sized> { ... }
A reader-writer lock
This type of lock allows a number of readers or at most one writer at any point in time. The write portion of this lock typically allows modification of the underlying data (exclusive access) and the read portion of this lock typically allows for read-only access (shared access).
In comparison, a Mutex does not distinguish between readers or writers
that acquire the lock, therefore blocking any threads waiting for the lock to
become available. An RwLock will allow any number of readers to acquire the
lock as long as a writer is not holding the lock.
The priority policy of the lock is dependent on the underlying operating
system's implementation, and this type does not guarantee that any
particular policy will be used. In particular, a writer which is waiting to
acquire the lock in write might or might not block concurrent calls to
read, e.g.:
Potential deadlock example
// Thread 1 | // Thread 2
let _rg1 = lock.read(); |
| // will block
| let _wg = lock.write();
// may deadlock |
let _rg2 = lock.read(); |
The type parameter T represents the data that this lock protects. It is
required that T satisfies Send to be shared across threads and
Sync to allow concurrent access through readers. The RAII guards
returned from the locking methods implement Deref (and DerefMut
for the write methods) to allow access to the content of the lock.
Poisoning
An RwLock, like Mutex, will usually become poisoned on a panic. Note,
however, that an RwLock may only be poisoned if a panic occurs while it is
locked exclusively (write mode). If a panic occurs in any reader, then the
lock will not be poisoned.
Examples
use ;
use thread;
use Duration;
let data = new;
// Multiple readers can access in parallel.
for i in 0..3
sleep; // Wait for readers to start
// While all readers can proceed, a call to .write() has to wait for
let mut writable_data = data.write.unwrap;
println!;
*writable_data += 1;
Implementations
impl<T> RwLock<T>
const fn new(t: T) -> RwLock<T>Creates a new instance of an
RwLock<T>which is unlocked.Examples
use RwLock; let lock = new;fn get_cloned(self: &Self) -> Result<T, PoisonError<()>> where T: CloneReturns the contained value by cloning it.
Errors
This function will return an error if the
RwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock.Examples
use RwLock; let mut lock = new; assert_eq!;fn set(self: &Self, value: T) -> Result<(), PoisonError<T>>Sets the contained value.
Errors
This function will return an error containing the provided
valueif theRwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock.Examples
use RwLock; let mut lock = new; assert_eq!; lock.set.unwrap; assert_eq!;fn replace(self: &Self, value: T) -> LockResult<T>Replaces the contained value with
value, and returns the old contained value.Errors
This function will return an error containing the provided
valueif theRwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock.Examples
use RwLock; let mut lock = new; assert_eq!; assert_eq!;
impl<T: ?Sized> RwLock<T>
fn read(self: &Self) -> LockResult<RwLockReadGuard<'_, T>>Locks this
RwLockwith shared read access, blocking the current thread until it can be acquired.The calling thread will be blocked until there are no more writers which hold the lock. There may be other readers currently inside the lock when this method returns. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Returns an RAII guard which will release this thread's shared access once it is dropped.
Errors
This function will return an error if the
RwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock. The failure will occur immediately after the lock has been acquired. The acquired lock guard will be contained in the returned error.Panics
This function might panic when called if the lock is already held by the current thread in read or write mode.
Examples
use ; use thread; let lock = new; let c_lock = clone; let n = lock.read.unwrap; assert_eq!; spawn.join.unwrap;fn try_read(self: &Self) -> TryLockResult<RwLockReadGuard<'_, T>>Attempts to acquire this
RwLockwith shared read access.If the access could not be granted at this time, then
Erris returned. Otherwise, an RAII guard is returned which will release the shared access when it is dropped.This function does not block.
This function does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Errors
This function will return the
Poisonederror if theRwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock.Poisonedwill only be returned if the lock would have otherwise been acquired. An acquired lock guard will be contained in the returned error.This function will return the
WouldBlockerror if theRwLockcould not be acquired because it was already locked exclusively.Examples
use RwLock; let lock = new; match lock.try_read ;fn write(self: &Self) -> LockResult<RwLockWriteGuard<'_, T>>Locks this
RwLockwith exclusive write access, blocking the current thread until it can be acquired.This function will not return while other writers or other readers currently have access to the lock.
Returns an RAII guard which will drop the write access of this
RwLockwhen dropped.Errors
This function will return an error if the
RwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock. An error will be returned when the lock is acquired. The acquired lock guard will be contained in the returned error.Panics
This function might panic when called if the lock is already held by the current thread in read or write mode.
Examples
use RwLock; let lock = new; let mut n = lock.write.unwrap; *n = 2; assert!;fn try_write(self: &Self) -> TryLockResult<RwLockWriteGuard<'_, T>>Attempts to lock this
RwLockwith exclusive write access.If the lock could not be acquired at this time, then
Erris returned. Otherwise, an RAII guard is returned which will release the lock when it is dropped.This function does not block.
This function does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Errors
This function will return the
Poisonederror if theRwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock.Poisonedwill only be returned if the lock would have otherwise been acquired. An acquired lock guard will be contained in the returned error.This function will return the
WouldBlockerror if theRwLockcould not be acquired because it was already locked.Examples
use RwLock; let lock = new; let n = lock.read.unwrap; assert_eq!; assert!;fn is_poisoned(self: &Self) -> boolDetermines whether the lock is poisoned.
If another thread is active, the lock can still become poisoned at any time. You should not trust a
falsevalue for program correctness without additional synchronization.Examples
use ; use thread; let lock = new; let c_lock = clone; let _ = spawn.join; assert_eq!;fn clear_poison(self: &Self)Clear the poisoned state from a lock.
If the lock is poisoned, it will remain poisoned until this function is called. This allows recovering from a poisoned state and marking that it has recovered. For example, if the value is overwritten by a known-good value, then the lock can be marked as un-poisoned. Or possibly, the value could be inspected to determine if it is in a consistent state, and if so the poison is removed.
Examples
use ; use thread; let lock = new; let c_lock = clone; let _ = spawn.join; assert_eq!; let guard = lock.write.unwrap_or_else; assert_eq!; assert_eq!;fn into_inner(self: Self) -> LockResult<T> where T: SizedConsumes this
RwLock, returning the underlying data.Errors
This function will return an error containing the underlying data if the
RwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock. An error will only be returned if the lock would have otherwise been acquired.Examples
use RwLock; let lock = new; assert_eq!;fn get_mut(self: &mut Self) -> LockResult<&mut T>Returns a mutable reference to the underlying data.
Since this call borrows the
RwLockmutably, no actual locking needs to take place -- the mutable borrow statically guarantees no new locks can be acquired while this reference exists. Note that this method does not clear any previously abandoned locks (e.g., via [forget()] on aRwLockReadGuardorRwLockWriteGuard).Errors
This function will return an error containing a mutable reference to the underlying data if the
RwLockis poisoned. AnRwLockis poisoned whenever a writer panics while holding an exclusive lock. An error will only be returned if the lock would have otherwise been acquired.Examples
use RwLock; let mut lock = new; *lock.get_mut.unwrap = 10; assert_eq!;const fn data_ptr(self: &Self) -> *mut TReturns a raw pointer to the underlying data.
The returned pointer is always non-null and properly aligned, but it is the user's responsibility to ensure that any reads and writes through it are properly synchronized to avoid data races, and that it is not read or written through after the lock is dropped.
impl<T> Any for RwLock<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RwLock<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RwLock<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for RwLock<T>
impl<T> From for RwLock<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> From for RwLock<T>
fn from(t: T) -> SelfCreates a new instance of an
RwLock<T>which is unlocked. This is equivalent toRwLock::new.
impl<T> From for RwLock<T>
fn from(t: never) -> T
impl<T> Unpin for RwLock<T>
impl<T> UnsafeUnpin for RwLock<T>
impl<T, U> Into for RwLock<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RwLock<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RwLock<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: ?Sized + Send + Sync> Sync for RwLock<T>
impl<T: ?Sized + Send> Send for RwLock<T>
impl<T: ?Sized + fmt::Debug> Debug for RwLock<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> RefUnwindSafe for RwLock<T>
impl<T: ?Sized> UnwindSafe for RwLock<T>
impl<T: Default> Default for RwLock<T>
fn default() -> RwLock<T>Creates a new
RwLock<T>, with theDefaultvalue for T.