pub struct MappedRwLockReadGuard<'rwlock, T: ?Sized + 'rwlock> { /* private fields */ }
mapped_lock_guards #117108)
RAII structure used to release the shared read access of a lock when dropped, which can point to a subfield of the protected data.
This structure is created by the map and filter_map methods on RwLockReadGuard.
impl<'rwlock, T: ?Sized> MappedRwLockReadGuard<'rwlock, T>
pub fn map<U, F>(orig: Self, f: F) -> MappedRwLockReadGuard<'rwlock, U>where
F: FnOnce(&T) -> &U,
U: ?Sized,mapped_lock_guards #117108)
Makes a MappedRwLockReadGuard for a component of the borrowed data, e.g. an enum variant.
The RwLock is already locked for reading, so this cannot fail.
This is an associated function that needs to be used as MappedRwLockReadGuard::map(...). A method would interfere with methods of the same name on the contents of the MappedRwLockReadGuard used through Deref.
If the closure panics, the guard will be dropped (unlocked) and the RwLock will not be poisoned.
pub fn filter_map<U, F>(
orig: Self,
f: F,
) -> Result<MappedRwLockReadGuard<'rwlock, U>, Self>where
F: FnOnce(&T) -> Option<&U>,
U: ?Sized,mapped_lock_guards #117108)
Makes a MappedRwLockReadGuard for a component of the borrowed data. The original guard is returned as an Err(...) if the closure returns None.
The RwLock is already locked for reading, so this cannot fail.
This is an associated function that needs to be used as MappedRwLockReadGuard::filter_map(...). A method would interfere with methods of the same name on the contents of the MappedRwLockReadGuard used through Deref.
If the closure panics, the guard will be dropped (unlocked) and the RwLock will not be poisoned.
impl<T: ?Sized + Debug> Debug for MappedRwLockReadGuard<'_, T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> Deref for MappedRwLockReadGuard<'_, T>
type Target = T
fn deref(&self) -> &T
impl<T: ?Sized + Display> Display for MappedRwLockReadGuard<'_, T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> Drop for MappedRwLockReadGuard<'_, T>
impl<T: ?Sized> !Send for MappedRwLockReadGuard<'_, T>
impl<T: ?Sized + Sync> Sync for MappedRwLockReadGuard<'_, T>
impl<'rwlock, T> Freeze for MappedRwLockReadGuard<'rwlock, T>where
T: ?Sized,impl<'rwlock, T> RefUnwindSafe for MappedRwLockReadGuard<'rwlock, T>where
T: RefUnwindSafe + ?Sized,impl<'rwlock, T> Unpin for MappedRwLockReadGuard<'rwlock, T>where
T: ?Sized,impl<'rwlock, T> UnwindSafe for MappedRwLockReadGuard<'rwlock, T>where
T: RefUnwindSafe + ?Sized,impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<P, T> Receiver for Pwhere
P: Deref<Target = T> + ?Sized,
T: ?Sized,type Target = T
arbitrary_self_types #44874)
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/poison/struct.MappedRwLockReadGuard.html