pub struct Barrier { /* private fields */ }
A barrier enables multiple threads to synchronize the beginning of some computation.
use std::sync::Barrier;
use std::thread;
let n = 10;
let barrier = Barrier::new(n);
thread::scope(|s| {
for _ in 0..n {
// The same messages will be printed together.
// You will NOT see any interleaving.
s.spawn(|| {
println!("before wait");
barrier.wait();
println!("after wait");
});
}
});impl Barrier
pub const fn new(n: usize) -> Barrier
Creates a new barrier that can block a given number of threads.
A barrier will block all threads which call wait() until the nth thread calls wait(), and then wake up all threads at once.
use std::sync::Barrier; let barrier = Barrier::new(10);
pub fn wait(&self) -> BarrierWaitResult
Blocks the current thread until all threads have rendezvoused here.
Barriers are re-usable after all threads have rendezvoused once, and can be used continuously.
A single (arbitrary) thread will receive a BarrierWaitResult that returns true from BarrierWaitResult::is_leader() when returning from this function, and all other threads will receive a result that will return false from BarrierWaitResult::is_leader().
use std::sync::Barrier;
use std::thread;
let n = 10;
let barrier = Barrier::new(n);
thread::scope(|s| {
for _ in 0..n {
// The same messages will be printed together.
// You will NOT see any interleaving.
s.spawn(|| {
println!("before wait");
barrier.wait();
println!("after wait");
});
}
});impl Debug for Barrier
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl RefUnwindSafe for Barrier
impl !Freeze for Barrier
impl Send for Barrier
impl Sync for Barrier
impl Unpin for Barrier
impl UnwindSafe for Barrier
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/struct.Barrier.html