pub struct BarrierWaitResult(/* private fields */);
A BarrierWaitResult is returned by Barrier::wait() when all threads in the Barrier have rendezvoused.
use std::sync::Barrier; let barrier = Barrier::new(1); let barrier_wait_result = barrier.wait();
impl BarrierWaitResult
pub fn is_leader(&self) -> bool
Returns true if this thread is the “leader thread” for the call to Barrier::wait().
Only one thread will have true returned from their result, all other threads will have false returned.
use std::sync::Barrier;
let barrier = Barrier::new(1);
let barrier_wait_result = barrier.wait();
println!("{:?}", barrier_wait_result.is_leader());impl Debug for BarrierWaitResult
impl Freeze for BarrierWaitResult
impl RefUnwindSafe for BarrierWaitResult
impl Send for BarrierWaitResult
impl Sync for BarrierWaitResult
impl Unpin for BarrierWaitResult
impl UnwindSafe for BarrierWaitResult
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/struct.BarrierWaitResult.html