pub struct OnceState { /* private fields */ }
State yielded to Once::call_once_force()’s closure parameter. The state can be used to query the poison status of the Once.
impl OnceState
pub fn is_poisoned(&self) -> bool
Returns true if the associated Once was poisoned prior to the invocation of the closure passed to Once::call_once_force().
A poisoned Once:
use std::sync::Once;
use std::thread;
static INIT: Once = Once::new();
// poison the once
let handle = thread::spawn(|| {
INIT.call_once(|| panic!());
});
assert!(handle.join().is_err());
INIT.call_once_force(|state| {
assert!(state.is_poisoned());
});An unpoisoned Once:
use std::sync::Once;
static INIT: Once = Once::new();
INIT.call_once_force(|state| {
assert!(!state.is_poisoned());
});impl Debug for OnceState
impl !Freeze for OnceState
impl !RefUnwindSafe for OnceState
impl Send for OnceState
impl !Sync for OnceState
impl Unpin for OnceState
impl UnwindSafe for OnceState
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/struct.OnceState.html