W3cubDocs

/Rust

Function set_permissions_nofollow

pub fn set_permissions_nofollow<P: AsRef<Path>>(
    path: P,
    perm: Permissions,
) -> Result<()>
🔬This is a nightly-only experimental API. (set_permissions_nofollow #141607)

Set the permissions of a file, unless it is a symlink.

Note that the non-final path elements are allowed to be symlinks.

Platform-specific behavior

Currently unimplemented on Windows.

On Unix platforms, this results in a FilesystemLoop error if the last element is a symlink.

This behavior may change in the future.

© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/fs/fn.set_permissions_nofollow.html