pub trait FunnelShift: Copy + 'static {
// Required methods
unsafe fn unchecked_funnel_shl(self, rhs: Self, shift: u32) -> Self;
unsafe fn unchecked_funnel_shr(self, rhs: Self, shift: u32) -> Self;
}
core_intrinsics_fallbacks)
unsafe fn unchecked_funnel_shl(self, rhs: Self, shift: u32) -> Self
core_intrinsics_fallbacks)
See super::unchecked_funnel_shl; we just need the trait indirection to handle different types since calling intrinsics with generics doesn’t work.
unsafe fn unchecked_funnel_shr(self, rhs: Self, shift: u32) -> Self
core_intrinsics_fallbacks)
See super::unchecked_funnel_shr; we just need the trait indirection to handle different types since calling intrinsics with generics doesn’t work.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
impl FunnelShift for u8
impl FunnelShift for u16
impl FunnelShift for u32
impl FunnelShift for u64
impl FunnelShift for u128
impl FunnelShift for usize
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/intrinsics/fallback/trait.FunnelShift.html