Enum ErrorKind
enum ErrorKind
A list specifying general categories of I/O error.
This list is intended to grow over time and it is not recommended to exhaustively match against it.
It is used with the io::Error type.
Handling errors and matching on ErrorKind
In application code, use match for the ErrorKind values you are
expecting; use _ to match "all other errors".
In comprehensive and thorough tests that want to verify that a test doesn't
return any known incorrect error kind, you may want to cut-and-paste the
current full list of errors from here into your test code, and then match
_ as the correct case. This seems counterintuitive, but it will make your
tests more robust. In particular, if you want to verify that your code does
produce an unrecognized error kind, the robust solution is to check for all
the recognized error kinds and fail in those cases.
Variants
-
NotFound An entity was not found, often a file.
-
PermissionDenied The operation lacked the necessary privileges to complete.
-
ConnectionRefused The connection was refused by the remote server.
-
ConnectionReset The connection was reset by the remote server.
-
HostUnreachable The remote host is not reachable.
-
NetworkUnreachable The network containing the remote host is not reachable.
-
ConnectionAborted The connection was aborted (terminated) by the remote server.
-
NotConnected The network operation failed because it was not connected yet.
-
AddrInUse A socket address could not be bound because the address is already in use elsewhere.
-
AddrNotAvailable A nonexistent interface was requested or the requested address was not local.
-
NetworkDown The system's networking is down.
-
BrokenPipe The operation failed because a pipe was closed.
-
AlreadyExists An entity already exists, often a file.
-
WouldBlock The operation needs to block to complete, but the blocking operation was requested to not occur.
-
NotADirectory A filesystem object is, unexpectedly, not a directory.
For example, a filesystem path was specified where one of the intermediate directory components was, in fact, a plain file.
-
IsADirectory The filesystem object is, unexpectedly, a directory.
A directory was specified when a non-directory was expected.
-
DirectoryNotEmpty A non-empty directory was specified where an empty directory was expected.
-
ReadOnlyFilesystem The filesystem or storage medium is read-only, but a write operation was attempted.
-
FilesystemLoop Loop in the filesystem or IO subsystem; often, too many levels of symbolic links.
There was a loop (or excessively long chain) resolving a filesystem object or file IO object.
On Unix this is usually the result of a symbolic link loop; or, of exceeding the system-specific limit on the depth of symlink traversal.
-
StaleNetworkFileHandle Stale network file handle.
With some network filesystems, notably NFS, an open file (or directory) can be invalidated by problems with the network or server.
-
InvalidInput A parameter was incorrect.
-
InvalidData Data not valid for the operation were encountered.
Unlike
InvalidInput, this typically means that the operation parameters were valid, however the error was caused by malformed input data.For example, a function that reads a file into a string will error with
InvalidDataif the file's contents are not valid UTF-8.-
TimedOut The I/O operation's timeout expired, causing it to be canceled.
-
WriteZero An error returned when an operation could not be completed because a call to
writereturnedOk(0).This typically means that an operation could only succeed if it wrote a particular number of bytes but only a smaller number of bytes could be written.
-
StorageFull The underlying storage (typically, a filesystem) is full.
This does not include out of quota errors.
-
NotSeekable Seek on unseekable file.
Seeking was attempted on an open file handle which is not suitable for seeking - for example, on Unix, a named pipe opened with
File::open.-
QuotaExceeded Filesystem quota or some other kind of quota was exceeded.
-
FileTooLarge File larger than allowed or supported.
This might arise from a hard limit of the underlying filesystem or file access API, or from an administratively imposed resource limitation. Simple disk full, and out of quota, have their own errors.
-
ResourceBusy Resource is busy.
-
ExecutableFileBusy Executable file is busy.
An attempt was made to write to a file which is also in use as a running program. (Not all operating systems detect this situation.)
-
Deadlock Deadlock (avoided).
A file locking operation would result in deadlock. This situation is typically detected, if at all, on a best-effort basis.
-
CrossesDevices Cross-device or cross-filesystem (hard) link or rename.
-
TooManyLinks Too many (hard) links to the same filesystem object.
The filesystem does not support making so many hardlinks to the same file.
-
InvalidFilename A filename was invalid.
This error can also occur if a length limit for a name was exceeded.
-
ArgumentListTooLong Program argument list too long.
When trying to run an external program, a system or process limit on the size of the arguments would have been exceeded.
-
Interrupted This operation was interrupted.
Interrupted operations can typically be retried.
-
Unsupported This operation is unsupported on this platform.
This means that the operation can never succeed.
-
UnexpectedEof An error returned when an operation could not be completed because an "end of file" was reached prematurely.
This typically means that an operation could only succeed if it read a particular number of bytes but only a smaller number of bytes could be read.
-
OutOfMemory An operation could not be completed, because it failed to allocate enough memory.
-
InProgress The operation was partially successful and needs to be checked later on due to not blocking.
-
Other A custom error that does not fall under any other I/O error kind.
This can be used to construct your own
Errors that do not match anyErrorKind.This
ErrorKindis not used by the standard library.Errors from the standard library that do not fall under any of the I/O error kinds cannot be
matched on, and will only match a wildcard (_) pattern. NewErrorKinds might be added in the future for some of those.
Implementations
impl Clone for ErrorKind
fn clone(self: &Self) -> ErrorKind
impl Copy for ErrorKind
impl Debug for ErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ErrorKind
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> ResultShows a human-readable description of the
ErrorKind.This is similar to
impl Display for Error, but doesn't require first converting to Error.Examples
use ErrorKind; assert_eq!;
impl Eq for ErrorKind
impl Freeze for ErrorKind
impl Hash for ErrorKind
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for ErrorKind
fn cmp(self: &Self, other: &ErrorKind) -> Ordering
impl PartialEq for ErrorKind
fn eq(self: &Self, other: &ErrorKind) -> bool
impl PartialOrd for ErrorKind
fn partial_cmp(self: &Self, other: &ErrorKind) -> Option<Ordering>
impl RefUnwindSafe for ErrorKind
impl Send for ErrorKind
impl StructuralPartialEq for ErrorKind
impl Sync for ErrorKind
impl Unpin for ErrorKind
impl UnsafeUnpin for ErrorKind
impl UnwindSafe for ErrorKind
impl<T> Any for ErrorKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ErrorKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ErrorKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ErrorKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ErrorKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ErrorKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for ErrorKind
fn to_string(self: &Self) -> String
impl<T, U> Into for ErrorKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ErrorKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ErrorKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>