Function empty
const fn empty() -> Empty
Creates a value that is always at EOF for reads, and ignores all data written.
All calls to write on the returned instance will return Ok(buf.len())
and the contents of the buffer will not be inspected.
All calls to read from the returned reader will return Ok(0).
Examples
use ;
let buffer = vec!;
let num_bytes = empty.write.unwrap;
assert_eq!;
use ;
let mut buffer = Stringnew;
empty.read_to_string.unwrap;
assert!;