Function repeat
const fn repeat(byte: u8) -> Repeat
Creates an instance of a reader that infinitely repeats one byte.
All reads from this reader will succeed by filling the specified buffer with the given byte.
Examples
use ;
let mut buffer = ;
repeat.read_exact.unwrap;
assert_eq!;