Function sink
const fn sink() -> Sink
Creates an instance of a writer which will successfully consume all data.
All calls to write on the returned instance will return Ok(buf.len())
and the contents of the buffer will not be inspected.
Examples
use ;
let buffer = vec!;
let num_bytes = sink.write.unwrap;
assert_eq!;