Struct IntoInnerError
struct IntoInnerError<W>(_, _)
An error returned by BufWriter::into_inner which combines an error that
happened while writing out the buffer, and the buffered writer object
which may be used to recover from the condition.
Examples
use std::io::BufWriter;
use std::net::TcpStream;
let mut stream = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap());
// do stuff with the stream
// we want to get our `TcpStream` back, so let's try:
let stream = match stream.into_inner() {
Ok(s) => s,
Err(e) => {
// Here, e is an IntoInnerError
panic!("An error occurred");
}
};
Implementations
impl<W> IntoInnerError<W>
fn error(self: &Self) -> &ErrorReturns the error which caused the call to [
BufWriter::into_inner()] to fail.This error was returned when attempting to write the internal buffer.
Examples
use std::io::BufWriter; use std::net::TcpStream; let mut stream = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap()); // do stuff with the stream // we want to get our `TcpStream` back, so let's try: let stream = match stream.into_inner() { Ok(s) => s, Err(e) => { // Here, e is an IntoInnerError, let's log the inner error. // // We'll just 'log' to stdout for this example. println!("{}", e.error()); panic!("An unexpected error occurred."); } };fn into_inner(self: Self) -> WReturns the buffered writer instance which generated the error.
The returned object can be used for error recovery, such as re-inspecting the buffer.
Examples
use std::io::BufWriter; use std::net::TcpStream; let mut stream = BufWriter::new(TcpStream::connect("127.0.0.1:34254").unwrap()); // do stuff with the stream // we want to get our `TcpStream` back, so let's try: let stream = match stream.into_inner() { Ok(s) => s, Err(e) => { // Here, e is an IntoInnerError, let's re-examine the buffer: let buffer = e.into_inner(); // do stuff to try to recover // afterwards, let's just return the stream buffer.into_inner().unwrap() } };fn into_error(self: Self) -> ErrorConsumes the
IntoInnerErrorand returns the error which caused the call to [BufWriter::into_inner()] to fail. Unlikeerror, this can be used to obtain ownership of the underlying error.Example
use ; let mut not_enough_space = ; let mut stream = new; write!.unwrap; let into_inner_err = stream.into_inner.expect_err; let err = into_inner_err.into_error; assert_eq!;fn into_parts(self: Self) -> (Error, W)Consumes the
IntoInnerErrorand returns the error which caused the call to [BufWriter::into_inner()] to fail, and the underlying writer.This can be used to simply obtain ownership of the underlying error; it can also be used for advanced error recovery.
Example
use ; let mut not_enough_space = ; let mut stream = new; write!.unwrap; let into_inner_err = stream.into_inner.expect_err; let = into_inner_err.into_parts; assert_eq!; assert_eq!;
impl<T> Any for IntoInnerError<W>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for IntoInnerError<W>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for IntoInnerError<W>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for IntoInnerError<W>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for IntoInnerError<W>
fn to_string(self: &Self) -> String
impl<T, U> Into for IntoInnerError<W>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for IntoInnerError<W>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for IntoInnerError<W>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<W> Display for IntoInnerError<W>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<W> Freeze for IntoInnerError<W>
impl<W> RefUnwindSafe for IntoInnerError<W>
impl<W> Send for IntoInnerError<W>
impl<W> Sync for IntoInnerError<W>
impl<W> Unpin for IntoInnerError<W>
impl<W> UnsafeUnpin for IntoInnerError<W>
impl<W> UnwindSafe for IntoInnerError<W>
impl<W: $crate::fmt::Debug> Debug for IntoInnerError<W>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result