Struct Sink
struct Sink
A writer which will move data into the void.
This struct is generally created by calling [sink()]. Please
see the documentation of [sink()] for more details.
Implementations
impl Clone for Sink
fn clone(self: &Self) -> Sink
impl Copy for Sink
impl Debug for Sink
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Sink
fn default() -> Sink
impl Freeze for Sink
impl RefUnwindSafe for Sink
impl Send for Sink
impl Sync for Sink
impl Unpin for Sink
impl UnsafeUnpin for Sink
impl UnwindSafe for Sink
impl Write for Sink
fn write(self: &mut Self, buf: &[u8]) -> Result<usize>fn write_vectored(self: &mut Self, bufs: &[IoSlice<'_>]) -> Result<usize>fn is_write_vectored(self: &Self) -> boolfn write_all(self: &mut Self, _buf: &[u8]) -> Result<()>fn write_all_vectored(self: &mut Self, _bufs: &mut [IoSlice<'_>]) -> Result<()>fn write_fmt(self: &mut Self, _args: Arguments<'_>) -> Result<()>fn flush(self: &mut Self) -> Result<()>
impl<T> Any for Sink
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Sink
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Sink
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Sink
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Sink
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Sink
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Sink
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Sink
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Sink
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>