Type Alias RawOsError

type RawOsError = i32

The type of raw OS error codes returned by Error::raw_os_error.

This is an i32 on all currently supported platforms, but platforms added in the future (such as UEFI) may use a different primitive type like usize. Use asor into conversions where applicable to ensure maximum portability.