Struct UdpSocket
struct UdpSocket(_)
A UDP socket.
After creating a UdpSocket by binding it to a socket address, data can be
sent to and received from any other socket address.
Although UDP is a connectionless protocol, this implementation provides an interface
to set an address where data should be sent and received from. After setting a remote
address with connect, data can be sent to and received from that address with
send and recv.
As stated in the User Datagram Protocol's specification in IETF RFC 768, UDP is
an unordered, unreliable protocol; refer to TcpListener and TcpStream for TCP
primitives.
Examples
use std::net::UdpSocket;
fn main() -> std::io::Result<()> {
{
let socket = UdpSocket::bind("127.0.0.1:34254")?;
// Receives a single datagram message on the socket. If `buf` is too small to hold
// the message, it will be cut off.
let mut buf = [0; 10];
let (amt, src) = socket.recv_from(&mut buf)?;
// Redeclare `buf` as slice of the received data and send reverse data back to origin.
let buf = &mut buf[..amt];
buf.reverse();
socket.send_to(buf, &src)?;
} // the socket is closed here
Ok(())
}
Implementations
impl UdpSocket
fn bind<A: ToSocketAddrs>(addr: A) -> Result<UdpSocket>Creates a UDP socket from the given address.
The address type can be any implementor of
ToSocketAddrstrait. See its documentation for concrete examples.If
addryields multiple addresses,bindwill be attempted with each of the addresses until one succeeds and returns the socket. If none of the addresses succeed in creating a socket, the error returned from the last attempt (the last address) is returned.Examples
Creates a UDP socket bound to
127.0.0.1:3400:use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:3400").expect("couldn't bind to address");Creates a UDP socket bound to
127.0.0.1:3400. If the socket cannot be bound to that address, create a UDP socket bound to127.0.0.1:3401:use std::net::{SocketAddr, UdpSocket}; let addrs = [ SocketAddr::from(([127, 0, 0, 1], 3400)), SocketAddr::from(([127, 0, 0, 1], 3401)), ]; let socket = UdpSocket::bind(&addrs[..]).expect("couldn't bind to address");Creates a UDP socket bound to a port assigned by the operating system at
127.0.0.1.use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:0").unwrap();Note that
binddeclares the scope of your network connection. You can only receive datagrams from and send datagrams to participants in that view of the network. For instance, binding to a loopback address as in the example above will prevent you from sending datagrams to another device in your local network.In order to limit your view of the network the least,
bindtoIpv4Addr::UNSPECIFIEDorIpv6Addr::UNSPECIFIED.fn recv_from(self: &Self, buf: &mut [u8]) -> Result<(usize, SocketAddr)>Receives a single datagram message on the socket. On success, returns the number of bytes read and the origin.
The function must be called with valid byte array
bufof sufficient size to hold the message bytes. If a message is too long to fit in the supplied buffer, excess bytes may be discarded.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); let mut buf = [0; 10]; let (number_of_bytes, src_addr) = socket.recv_from(&mut buf) .expect("Didn't receive data"); let filled_buf = &mut buf[..number_of_bytes];fn peek_from(self: &Self, buf: &mut [u8]) -> Result<(usize, SocketAddr)>Receives a single datagram message on the socket, without removing it from the queue. On success, returns the number of bytes read and the origin.
The function must be called with valid byte array
bufof sufficient size to hold the message bytes. If a message is too long to fit in the supplied buffer, excess bytes may be discarded.Successive calls return the same data. This is accomplished by passing
MSG_PEEKas a flag to the underlyingrecvfromsystem call.Do not use this function to implement busy waiting, instead use
libc::pollto synchronize IO events on one or more sockets.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); let mut buf = [0; 10]; let (number_of_bytes, src_addr) = socket.peek_from(&mut buf) .expect("Didn't receive data"); let filled_buf = &mut buf[..number_of_bytes];fn send_to<A: ToSocketAddrs>(self: &Self, buf: &[u8], addr: A) -> Result<usize>Sends data on the socket to the given address. On success, returns the number of bytes written. Note that the operating system may refuse buffers larger than 65507. However, partial writes are not possible until buffer sizes above
i32::MAX.Address type can be any implementor of
ToSocketAddrstrait. See its documentation for concrete examples.It is possible for
addrto yield multiple addresses, butsend_towill only send data to the first address yielded byaddr.This will return an error when the IP version of the local socket does not match that returned from
ToSocketAddrs.See Issue #34202 for more details.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.send_to(&[0; 10], "127.0.0.1:4242").expect("couldn't send data");fn peer_addr(self: &Self) -> Result<SocketAddr>Returns the socket address of the remote peer this socket was connected to.
Examples
use std::net::{Ipv4Addr, SocketAddr, SocketAddrV4, UdpSocket}; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.connect("192.168.0.1:41203").expect("couldn't connect to address"); assert_eq!(socket.peer_addr().unwrap(), SocketAddr::V4(SocketAddrV4::new(Ipv4Addr::new(192, 168, 0, 1), 41203)));If the socket isn't connected, it will return a
NotConnectederror.use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); assert_eq!(socket.peer_addr().unwrap_err().kind(), std::io::ErrorKind::NotConnected);fn local_addr(self: &Self) -> Result<SocketAddr>Returns the socket address that this socket was created from.
Examples
use std::net::{Ipv4Addr, SocketAddr, SocketAddrV4, UdpSocket}; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); assert_eq!(socket.local_addr().unwrap(), SocketAddr::V4(SocketAddrV4::new(Ipv4Addr::new(127, 0, 0, 1), 34254)));fn try_clone(self: &Self) -> Result<UdpSocket>Creates a new independently owned handle to the underlying socket.
The returned
UdpSocketis a reference to the same socket that this object references. Both handles will read and write the same port, and options set on one socket will be propagated to the other.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); let socket_clone = socket.try_clone().expect("couldn't clone the socket");fn set_read_timeout(self: &Self, dur: Option<Duration>) -> Result<()>Sets the read timeout to the timeout specified.
If the value specified is
None, thenreadcalls will block indefinitely. AnErris returned if the zeroDurationis passed to this method.Platform-specific behavior
Platforms may return a different error code whenever a read times out as a result of setting this option. For example Unix typically returns an error of the kind
WouldBlock, but Windows may returnTimedOut.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_read_timeout(None).expect("set_read_timeout call failed");An
Erris returned if the zeroDurationis passed to this method:use std::io; use std::net::UdpSocket; use std::time::Duration; let socket = UdpSocket::bind("127.0.0.1:34254").unwrap(); let result = socket.set_read_timeout(Some(Duration::new(0, 0))); let err = result.unwrap_err(); assert_eq!(err.kind(), io::ErrorKind::InvalidInput)fn set_write_timeout(self: &Self, dur: Option<Duration>) -> Result<()>Sets the write timeout to the timeout specified.
If the value specified is
None, thenwritecalls will block indefinitely. AnErris returned if the zeroDurationis passed to this method.Platform-specific behavior
Platforms may return a different error code whenever a write times out as a result of setting this option. For example Unix typically returns an error of the kind
WouldBlock, but Windows may returnTimedOut.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_write_timeout(None).expect("set_write_timeout call failed");An
Erris returned if the zeroDurationis passed to this method:use std::io; use std::net::UdpSocket; use std::time::Duration; let socket = UdpSocket::bind("127.0.0.1:34254").unwrap(); let result = socket.set_write_timeout(Some(Duration::new(0, 0))); let err = result.unwrap_err(); assert_eq!(err.kind(), io::ErrorKind::InvalidInput)fn read_timeout(self: &Self) -> Result<Option<Duration>>Returns the read timeout of this socket.
If the timeout is
None, thenreadcalls will block indefinitely.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_read_timeout(None).expect("set_read_timeout call failed"); assert_eq!(socket.read_timeout().unwrap(), None);fn write_timeout(self: &Self) -> Result<Option<Duration>>Returns the write timeout of this socket.
If the timeout is
None, thenwritecalls will block indefinitely.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_write_timeout(None).expect("set_write_timeout call failed"); assert_eq!(socket.write_timeout().unwrap(), None);fn set_broadcast(self: &Self, broadcast: bool) -> Result<()>Sets the value of the
SO_BROADCASToption for this socket.When enabled, this socket is allowed to send packets to a broadcast address.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_broadcast(false).expect("set_broadcast call failed");fn broadcast(self: &Self) -> Result<bool>Gets the value of the
SO_BROADCASToption for this socket.For more information about this option, see
UdpSocket::set_broadcast.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_broadcast(false).expect("set_broadcast call failed"); assert_eq!(socket.broadcast().unwrap(), false);fn set_multicast_loop_v4(self: &Self, multicast_loop_v4: bool) -> Result<()>Sets the value of the
IP_MULTICAST_LOOPoption for this socket.If enabled, multicast packets will be looped back to the local socket. Note that this might not have any effect on IPv6 sockets.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_multicast_loop_v4(false).expect("set_multicast_loop_v4 call failed");fn multicast_loop_v4(self: &Self) -> Result<bool>Gets the value of the
IP_MULTICAST_LOOPoption for this socket.For more information about this option, see
UdpSocket::set_multicast_loop_v4.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_multicast_loop_v4(false).expect("set_multicast_loop_v4 call failed"); assert_eq!(socket.multicast_loop_v4().unwrap(), false);fn set_multicast_ttl_v4(self: &Self, multicast_ttl_v4: u32) -> Result<()>Sets the value of the
IP_MULTICAST_TTLoption for this socket.Indicates the time-to-live value of outgoing multicast packets for this socket. The default value is 1 which means that multicast packets don't leave the local network unless explicitly requested.
Note that this might not have any effect on IPv6 sockets.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_multicast_ttl_v4(42).expect("set_multicast_ttl_v4 call failed");fn multicast_ttl_v4(self: &Self) -> Result<u32>Gets the value of the
IP_MULTICAST_TTLoption for this socket.For more information about this option, see
UdpSocket::set_multicast_ttl_v4.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_multicast_ttl_v4(42).expect("set_multicast_ttl_v4 call failed"); assert_eq!(socket.multicast_ttl_v4().unwrap(), 42);fn set_multicast_loop_v6(self: &Self, multicast_loop_v6: bool) -> Result<()>Sets the value of the
IPV6_MULTICAST_LOOPoption for this socket.Controls whether this socket sees the multicast packets it sends itself. Note that this might not have any affect on IPv4 sockets.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_multicast_loop_v6(false).expect("set_multicast_loop_v6 call failed");fn multicast_loop_v6(self: &Self) -> Result<bool>Gets the value of the
IPV6_MULTICAST_LOOPoption for this socket.For more information about this option, see
UdpSocket::set_multicast_loop_v6.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_multicast_loop_v6(false).expect("set_multicast_loop_v6 call failed"); assert_eq!(socket.multicast_loop_v6().unwrap(), false);fn set_ttl(self: &Self, ttl: u32) -> Result<()>Sets the value for the
IP_TTLoption on this socket.This value sets the time-to-live field that is used in every packet sent from this socket.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_ttl(42).expect("set_ttl call failed");fn ttl(self: &Self) -> Result<u32>Gets the value of the
IP_TTLoption for this socket.For more information about this option, see
UdpSocket::set_ttl.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.set_ttl(42).expect("set_ttl call failed"); assert_eq!(socket.ttl().unwrap(), 42);fn join_multicast_v4(self: &Self, multiaddr: &Ipv4Addr, interface: &Ipv4Addr) -> Result<()>Executes an operation of the
IP_ADD_MEMBERSHIPtype.This function specifies a new multicast group for this socket to join. The address must be a valid multicast address, and
interfaceis the address of the local interface with which the system should join the multicast group. If it's equal toUNSPECIFIEDthen an appropriate interface is chosen by the system.fn join_multicast_v6(self: &Self, multiaddr: &Ipv6Addr, interface: u32) -> Result<()>Executes an operation of the
IPV6_ADD_MEMBERSHIPtype.This function specifies a new multicast group for this socket to join. The address must be a valid multicast address, and
interfaceis the index of the interface to join/leave (or 0 to indicate any interface).fn leave_multicast_v4(self: &Self, multiaddr: &Ipv4Addr, interface: &Ipv4Addr) -> Result<()>Executes an operation of the
IP_DROP_MEMBERSHIPtype.For more information about this option, see
UdpSocket::join_multicast_v4.fn leave_multicast_v6(self: &Self, multiaddr: &Ipv6Addr, interface: u32) -> Result<()>Executes an operation of the
IPV6_DROP_MEMBERSHIPtype.For more information about this option, see
UdpSocket::join_multicast_v6.fn take_error(self: &Self) -> Result<Option<Error>>Gets the value of the
SO_ERRORoption on this socket.This will retrieve the stored error in the underlying socket, clearing the field in the process. This can be useful for checking errors between calls.
Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); match socket.take_error() { Ok(Some(error)) => println!("UdpSocket error: {error:?}"), Ok(None) => println!("No error"), Err(error) => println!("UdpSocket.take_error failed: {error:?}"), }fn connect<A: ToSocketAddrs>(self: &Self, addr: A) -> Result<()>Connects this UDP socket to a remote address, allowing the
sendandrecvsyscalls to be used to send data and also applies filters to only receive data from the specified address.If
addryields multiple addresses,connectwill be attempted with each of the addresses until the underlying OS function returns no error. Note that usually, a successfulconnectcall does not specify that there is a remote server listening on the port, rather, such an error would only be detected after the first send. If the OS returns an error for each of the specified addresses, the error returned from the last connection attempt (the last address) is returned.Examples
Creates a UDP socket bound to
127.0.0.1:3400and connect the socket to127.0.0.1:8080:use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:3400").expect("couldn't bind to address"); socket.connect("127.0.0.1:8080").expect("connect function failed");Unlike in the TCP case, passing an array of addresses to the
connectfunction of a UDP socket is not a useful thing to do: The OS will be unable to determine whether something is listening on the remote address without the application sending data.If your first
connectis to a loopback address, subsequentconnects to non-loopback addresses might fail, depending on the platform.fn send(self: &Self, buf: &[u8]) -> Result<usize>Sends data on the socket to the remote address to which it is connected. On success, returns the number of bytes written. Note that the operating system may refuse buffers larger than 65507. However, partial writes are not possible until buffer sizes above
i32::MAX.UdpSocket::connectwill connect this socket to a remote address. This method will fail if the socket is not connected.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.connect("127.0.0.1:8080").expect("connect function failed"); socket.send(&[0, 1, 2]).expect("couldn't send message");fn recv(self: &Self, buf: &mut [u8]) -> Result<usize>Receives a single datagram message on the socket from the remote address to which it is connected. On success, returns the number of bytes read.
The function must be called with valid byte array
bufof sufficient size to hold the message bytes. If a message is too long to fit in the supplied buffer, excess bytes may be discarded.UdpSocket::connectwill connect this socket to a remote address. This method will fail if the socket is not connected.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.connect("127.0.0.1:8080").expect("connect function failed"); let mut buf = [0; 10]; match socket.recv(&mut buf) { Ok(received) => println!("received {received} bytes {:?}", &buf[..received]), Err(e) => println!("recv function failed: {e:?}"), }fn peek(self: &Self, buf: &mut [u8]) -> Result<usize>Receives single datagram on the socket from the remote address to which it is connected, without removing the message from input queue. On success, returns the number of bytes peeked.
The function must be called with valid byte array
bufof sufficient size to hold the message bytes. If a message is too long to fit in the supplied buffer, excess bytes may be discarded.Successive calls return the same data. This is accomplished by passing
MSG_PEEKas a flag to the underlyingrecvsystem call.Do not use this function to implement busy waiting, instead use
libc::pollto synchronize IO events on one or more sockets.UdpSocket::connectwill connect this socket to a remote address. This method will fail if the socket is not connected.Errors
This method will fail if the socket is not connected. The
connectmethod will connect this socket to a remote address.Examples
use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:34254").expect("couldn't bind to address"); socket.connect("127.0.0.1:8080").expect("connect function failed"); let mut buf = [0; 10]; match socket.peek(&mut buf) { Ok(received) => println!("received {received} bytes"), Err(e) => println!("peek function failed: {e:?}"), }fn set_nonblocking(self: &Self, nonblocking: bool) -> Result<()>Moves this UDP socket into or out of nonblocking mode.
This will result in
recv,recv_from,send, andsend_tosystem operations becoming nonblocking, i.e., immediately returning from their calls. If the IO operation is successful,Okis returned and no further action is required. If the IO operation could not be completed and needs to be retried, an error with kindio::ErrorKind::WouldBlockis returned.On Unix platforms, calling this method corresponds to calling
fcntlFIONBIO. On Windows calling this method corresponds to callingioctlsocketFIONBIO.Examples
Creates a UDP socket bound to
127.0.0.1:7878and read bytes in nonblocking mode:use std::io; use std::net::UdpSocket; let socket = UdpSocket::bind("127.0.0.1:7878").unwrap(); socket.set_nonblocking(true).unwrap(); # fn wait_for_fd() { unimplemented!() } let mut buf = [0; 10]; let (num_bytes_read, _) = loop { match socket.recv_from(&mut buf) { Ok(n) => break n, Err(ref e) if e.kind() == io::ErrorKind::WouldBlock => { // wait until network socket is ready, typically implemented // via platform-specific APIs such as epoll or IOCP wait_for_fd(); } Err(e) => panic!("encountered IO error: {e}"), } }; println!("bytes: {:?}", &buf[..num_bytes_read]);
impl AsFd for UdpSocket
fn as_fd(self: &Self) -> BorrowedFd<'_>
impl AsRawFd for UdpSocket
fn as_raw_fd(self: &Self) -> RawFd
impl AsRawSocket for UdpSocket
fn as_raw_socket(self: &Self) -> RawSocket
impl AsSocket for UdpSocket
fn as_socket(self: &Self) -> BorrowedSocket<'_>
impl Debug for UdpSocket
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for UdpSocket
impl From for UdpSocket
fn from(owned_fd: OwnedFd) -> Self
impl From for UdpSocket
fn from(owned: OwnedSocket) -> Self
impl FromRawFd for UdpSocket
unsafe fn from_raw_fd(fd: RawFd) -> UdpSocket
impl FromRawSocket for UdpSocket
unsafe fn from_raw_socket(sock: RawSocket) -> UdpSocket
impl IntoRawFd for UdpSocket
fn into_raw_fd(self: Self) -> RawFd
impl IntoRawSocket for UdpSocket
fn into_raw_socket(self: Self) -> RawSocket
impl RefUnwindSafe for UdpSocket
impl Send for UdpSocket
impl Sync for UdpSocket
impl Unpin for UdpSocket
impl UnsafeUnpin for UdpSocket
impl UnwindSafe for UdpSocket
impl<T> Any for UdpSocket
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for UdpSocket
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for UdpSocket
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for UdpSocket
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for UdpSocket
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for UdpSocket
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for UdpSocket
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>