pub trait AsRawFd {
// Required method
fn as_raw_fd(&self) -> RawFd;
}
target_os=trusty or WASI or target_os=motor only.A trait to extract the raw file descriptor from an underlying object.
This is only available on unix and WASI platforms and must be imported in order to call the method. Windows platforms have a corresponding AsRawHandle and AsRawSocket set of traits.
fn as_raw_fd(&self) -> RawFd
Extracts the raw file descriptor.
This function is typically used to borrow an owned file descriptor. When used in this way, this method does not pass ownership of the raw file descriptor to the caller, and the file descriptor is only guaranteed to be valid while the original object has not yet been destroyed.
However, borrowing is not strictly required. See AsFd::as_fd for an API which strictly borrows a file descriptor.
use std::fs::File;
#[cfg(any(unix, target_os = "wasi"))]
use std::os::fd::{AsRawFd, RawFd};
let mut f = File::open("foo.txt")?;
// Note that `raw_fd` is only valid as long as `f` exists.
#[cfg(any(unix, target_os = "wasi"))]
let raw_fd: RawFd = f.as_raw_fd();impl AsRawFd for FileAvailable on non-target_os=trusty only.
impl AsRawFd for PipeReaderAvailable on non-target_os=trusty only.
impl AsRawFd for PipeWriterAvailable on non-target_os=trusty only.
impl AsRawFd for Stderr
impl AsRawFd for StdinAvailable on non-target_os=trusty only.
impl AsRawFd for Stdout
impl AsRawFd for TcpListenerAvailable on non-target_os=trusty only.
impl AsRawFd for TcpStreamAvailable on non-target_os=trusty only.
impl AsRawFd for UdpSocketAvailable on non-target_os=trusty only.
impl AsRawFd for ChildStderrAvailable on Unix only.
impl AsRawFd for ChildStdinAvailable on Unix only.
impl AsRawFd for ChildStdoutAvailable on Unix only.
impl AsRawFd for PidFdAvailable on Linux only.
impl AsRawFd for UnixDatagramAvailable on Unix only.
impl AsRawFd for UnixListenerAvailable on Unix only.
impl AsRawFd for UnixStreamAvailable on Unix only.
impl AsRawFd for BorrowedFd<'_>
impl AsRawFd for OwnedFd
impl AsRawFd for RawFd
impl<'a> AsRawFd for StderrLock<'a>
impl<'a> AsRawFd for StdinLock<'a>Available on non-target_os=trusty only.
impl<'a> AsRawFd for StdoutLock<'a>
impl<T: AsRawFd + ?Sized> AsRawFd for UniqueRc<T>
impl<T: AsRawFd> AsRawFd for Box<T>
impl<T: AsRawFd> AsRawFd for Rc<T>
impl<T: AsRawFd> AsRawFd for Arc<T>This impl allows implementing traits that require AsRawFd on Arc.
use std::net::UdpSocket;
use std::sync::Arc;
trait MyTrait: AsRawFd {
}
impl MyTrait for Arc<UdpSocket> {}
impl MyTrait for Box<UdpSocket> {}
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/os/fd/trait.AsRawFd.html