Trait FileTypeExt

trait FileTypeExt: Sealed

Windows-specific extensions to fs::FileType.

On Windows, a symbolic link knows whether it is a file or directory.

Required Methods

Returns true if this file type is a symbolic link that is also a directory.

Returns true if this file type is a symbolic link that is also a file.

Implementors