Trait AsRawHandle

trait AsRawHandle

Extracts raw handles.

Required Methods

fn as_raw_handle(self: &Self) -> RawHandle

Extracts the raw handle.

This function is typically used to borrow an owned handle. When used in this way, this method does not pass ownership of the raw handle to the caller, and the handle is only guaranteed to be valid while the original object has not yet been destroyed.

This function may return null, such as when called on Stdin, Stdout, or Stderr when the console is detached.

However, borrowing is not strictly required. See AsHandle::as_handle for an API which strictly borrows a handle.

Implementors