Trait AsRawHandle
trait AsRawHandle
Extracts raw handles.
Required Methods
fn as_raw_handle(self: &Self) -> RawHandleExtracts the raw handle.
This function is typically used to borrow an owned handle. When used in this way, this method does not pass ownership of the raw handle to the caller, and the handle is only guaranteed to be valid while the original object has not yet been destroyed.
This function may return null, such as when called on
Stdin,Stdout, orStderrwhen the console is detached.However, borrowing is not strictly required. See
AsHandle::as_handlefor an API which strictly borrows a handle.
Implementors
impl AsRawHandle for Stdoutimpl<'a> AsRawHandle for StdoutLock<'a>impl AsRawHandle for ChildStdinimpl AsRawHandle for Fileimpl<'a> AsRawHandle for StdinLock<'a>impl AsRawHandle for ChildStderrimpl AsRawHandle for OwnedHandleimpl<T> AsRawHandle for JoinHandle<T>impl AsRawHandle for BorrowedHandle<'_>impl AsRawHandle for PipeWriterimpl AsRawHandle for Childimpl AsRawHandle for Stdinimpl AsRawHandle for ChildStdoutimpl AsRawHandle for Stderrimpl AsRawHandle for PipeReaderimpl<'a> AsRawHandle for StderrLock<'a>