pub fn set_backtrace_style(style: BacktraceStyle)
panic_backtrace_config #93346)
Configures whether the default panic hook will capture and display a backtrace.
The default value for this setting may be set by the RUST_BACKTRACE environment variable; see the details in get_backtrace_style.
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/panic/fn.set_backtrace_style.html