Struct RwLock
struct RwLock<T: ?Sized> { ... }
A reader-writer lock that does not keep track of lock poisoning.
For more information about reader-writer locks, check out the documentation for the poisoning
variant of this lock (which can be found at poison::RwLock).
Examples
use RwLock;
let lock = new;
// many reader locks can be held at once
// read locks are dropped at this point
// only one write lock may be held, however
// write lock is dropped here
Implementations
impl<T> RwLock<T>
const fn new(t: T) -> RwLock<T>Creates a new instance of an
RwLock<T>which is unlocked.Examples
use RwLock; let lock = new;fn get_cloned(self: &Self) -> T where T: CloneReturns the contained value by cloning it.
Examples
use RwLock; let mut lock = new; assert_eq!;fn set(self: &Self, value: T)Sets the contained value.
Examples
use RwLock; let mut lock = new; assert_eq!; lock.set; assert_eq!;fn replace(self: &Self, value: T) -> TReplaces the contained value with
value, and returns the old contained value.Examples
use RwLock; let mut lock = new; assert_eq!; assert_eq!;
impl<T: ?Sized> RwLock<T>
fn read(self: &Self) -> RwLockReadGuard<'_, T>Locks this
RwLockwith shared read access, blocking the current thread until it can be acquired.The calling thread will be blocked until there are no more writers which hold the lock. There may be other readers currently inside the lock when this method returns. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Returns an RAII guard which will release this thread's shared access once it is dropped.
Panics
This function might panic when called if the lock is already held by the current thread.
Examples
use Arc; use RwLock; use thread; let lock = new; let c_lock = clone; let n = lock.read; assert_eq!; spawn.join.unwrap;fn try_read(self: &Self) -> TryLockResult<RwLockReadGuard<'_, T>>Attempts to acquire this
RwLockwith shared read access.If the access could not be granted at this time, then
Erris returned. Otherwise, an RAII guard is returned which will release the shared access when it is dropped.This function does not block.
This function does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Errors
This function will return the
WouldBlockerror if theRwLockcould not be acquired because it was already locked exclusively.Examples
use RwLock; let lock = new; match lock.try_read ;fn write(self: &Self) -> RwLockWriteGuard<'_, T>Locks this
RwLockwith exclusive write access, blocking the current thread until it can be acquired.This function will not return while other writers or other readers currently have access to the lock.
Returns an RAII guard which will drop the write access of this
RwLockwhen dropped.Panics
This function might panic when called if the lock is already held by the current thread.
Examples
use RwLock; let lock = new; let mut n = lock.write; *n = 2; assert!;fn try_write(self: &Self) -> TryLockResult<RwLockWriteGuard<'_, T>>Attempts to lock this
RwLockwith exclusive write access.If the lock could not be acquired at this time, then
Erris returned. Otherwise, an RAII guard is returned which will release the lock when it is dropped.This function does not block.
This function does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Errors
This function will return the
WouldBlockerror if theRwLockcould not be acquired because it was already locked.Examples
use RwLock; let lock = new; let n = lock.read; assert_eq!; assert!;fn into_inner(self: Self) -> T where T: SizedConsumes this
RwLock, returning the underlying data.Examples
use RwLock; let lock = new; assert_eq!;fn get_mut(self: &mut Self) -> &mut TReturns a mutable reference to the underlying data.
Since this call borrows the
RwLockmutably, no actual locking needs to take place -- the mutable borrow statically guarantees no new locks can be acquired while this reference exists. Note that this method does not clear any previously abandoned locks (e.g., via [forget()] on aRwLockReadGuardorRwLockWriteGuard).Examples
use RwLock; let mut lock = new; *lock.get_mut = 10; assert_eq!;const fn data_ptr(self: &Self) -> *mut TReturns a raw pointer to the underlying data.
The returned pointer is always non-null and properly aligned, but it is the user's responsibility to ensure that any reads and writes through it are properly synchronized to avoid data races, and that it is not read or written through after the lock is dropped.
fn with<F, R>(self: &Self, f: F) -> R where F: FnOnce(&T) -> RLocks this
RwLockwith shared read access to the underlying data by passing a reference to the given closure.This method acquires the lock, calls the provided closure with a reference to the data, and returns the result of the closure. The lock is released after the closure completes, even if it panics.
Examples
use RwLock; let rwlock = new; let result = rwlock.with; assert_eq!;fn with_mut<F, R>(self: &Self, f: F) -> R where F: FnOnce(&mut T) -> RLocks this
RwLockwith exclusive write access to the underlying data by passing a mutable reference to the given closure.This method acquires the lock, calls the provided closure with a mutable reference to the data, and returns the result of the closure. The lock is released after the closure completes, even if it panics.
Examples
use RwLock; let rwlock = new; let result = rwlock.with_mut; assert_eq!; assert_eq!;
impl<T> Any for RwLock<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RwLock<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RwLock<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for RwLock<T>
impl<T> From for RwLock<T>
fn from(t: T) -> SelfCreates a new instance of an
RwLock<T>which is unlocked. This is equivalent toRwLock::new.
impl<T> From for RwLock<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> From for RwLock<T>
fn from(t: never) -> T
impl<T> RefUnwindSafe for RwLock<T>
impl<T> Unpin for RwLock<T>
impl<T> UnsafeUnpin for RwLock<T>
impl<T> UnwindSafe for RwLock<T>
impl<T, U> Into for RwLock<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RwLock<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RwLock<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: ?Sized + Send + Sync> Sync for RwLock<T>
impl<T: ?Sized + Send> Send for RwLock<T>
impl<T: ?Sized + fmt::Debug> Debug for RwLock<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: Default> Default for RwLock<T>
fn default() -> RwLock<T>Creates a new
RwLock<T>, with theDefaultvalue for T.