pub struct RwLockWriteGuard<'rwlock, T: ?Sized + 'rwlock> { /* private fields */ }
nonpoison_rwlock #134645)
RAII structure used to release the exclusive write access of a lock when dropped.
This structure is created by the write and try_write methods on RwLock.
impl<'rwlock, T: ?Sized> RwLockWriteGuard<'rwlock, T>
pub fn downgrade(s: Self) -> RwLockReadGuard<'rwlock, T>
nonpoison_rwlock #134645)
Downgrades a write-locked RwLockWriteGuard into a read-locked RwLockReadGuard.
Since we have the RwLockWriteGuard, the RwLock must already be locked for writing, so this method cannot fail.
After downgrading, other readers will be allowed to read the protected data.
downgrade takes ownership of the RwLockWriteGuard and returns a RwLockReadGuard.
#![feature(nonpoison_rwlock)]
use std::sync::nonpoison::{RwLock, RwLockWriteGuard};
let rw = RwLock::new(0);
let mut write_guard = rw.write();
*write_guard = 42;
let read_guard = RwLockWriteGuard::downgrade(write_guard);
assert_eq!(42, *read_guard);downgrade will atomically change the state of the RwLock from exclusive mode into shared mode. This means that it is impossible for another writing thread to get in between a thread calling downgrade and any reads it performs after downgrading.
#![feature(nonpoison_rwlock)]
use std::sync::Arc;
use std::sync::nonpoison::{RwLock, RwLockWriteGuard};
let rw = Arc::new(RwLock::new(1));
// Put the lock in write mode.
let mut main_write_guard = rw.write();
let rw_clone = rw.clone();
let evil_handle = std::thread::spawn(move || {
// This will not return until the main thread drops the `main_read_guard`.
let mut evil_guard = rw_clone.write();
assert_eq!(*evil_guard, 2);
*evil_guard = 3;
});
*main_write_guard = 2;
// Atomically downgrade the write guard into a read guard.
let main_read_guard = RwLockWriteGuard::downgrade(main_write_guard);
// Since `downgrade` is atomic, the writer thread cannot have changed the protected data.
assert_eq!(*main_read_guard, 2, "`downgrade` was not atomic");pub fn map<U, F>(orig: Self, f: F) -> MappedRwLockWriteGuard<'rwlock, U>where
F: FnOnce(&mut T) -> &mut U,
U: ?Sized,mapped_lock_guards #117108)
Makes a MappedRwLockWriteGuard for a component of the borrowed data, e.g. an enum variant.
The RwLock is already locked for writing, so this cannot fail.
This is an associated function that needs to be used as RwLockWriteGuard::map(...). A method would interfere with methods of the same name on the contents of the RwLockWriteGuard used through Deref.
If the closure panics, the guard will be dropped (unlocked).
pub fn filter_map<U, F>(
orig: Self,
f: F,
) -> Result<MappedRwLockWriteGuard<'rwlock, U>, Self>where
F: FnOnce(&mut T) -> Option<&mut U>,
U: ?Sized,mapped_lock_guards #117108)
Makes a MappedRwLockWriteGuard for a component of the borrowed data. The original guard is returned as an Err(...) if the closure returns None.
The RwLock is already locked for writing, so this cannot fail.
This is an associated function that needs to be used as RwLockWriteGuard::filter_map(...). A method would interfere with methods of the same name on the contents of the RwLockWriteGuard used through Deref.
If the closure panics, the guard will be dropped (unlocked).
impl<T: ?Sized + Debug> Debug for RwLockWriteGuard<'_, T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> Deref for RwLockWriteGuard<'_, T>
type Target = T
fn deref(&self) -> &T
impl<T: ?Sized> DerefMut for RwLockWriteGuard<'_, T>
fn deref_mut(&mut self) -> &mut T
impl<T: ?Sized + Display> Display for RwLockWriteGuard<'_, T>
fn fmt(&self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> Drop for RwLockWriteGuard<'_, T>
impl<T: ?Sized> !Send for RwLockWriteGuard<'_, T>
impl<T: ?Sized + Sync> Sync for RwLockWriteGuard<'_, T>
impl<'rwlock, T> Freeze for RwLockWriteGuard<'rwlock, T>where
T: ?Sized,impl<'rwlock, T> !RefUnwindSafe for RwLockWriteGuard<'rwlock, T>
impl<'rwlock, T> Unpin for RwLockWriteGuard<'rwlock, T>where
T: ?Sized,impl<'rwlock, T> !UnwindSafe for RwLockWriteGuard<'rwlock, T>
impl<T> Any for Twhere
T: 'static + ?Sized,impl<T> Borrow<T> for Twhere
T: ?Sized,impl<T> BorrowMut<T> for Twhere
T: ?Sized,impl<T> From<T> for T
fn from(t: T) -> T
Returns the argument unchanged.
impl<T, U> Into<U> for Twhere
U: From<T>,fn into(self) -> U
Calls U::from(self).
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
impl<P, T> Receiver for Pwhere
P: Deref<Target = T> + ?Sized,
T: ?Sized,type Target = T
arbitrary_self_types #44874)
impl<T> ToString for Twhere
T: Display + ?Sized,impl<T, U> TryFrom<U> for Twhere
U: Into<T>,type Error = Infallible
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for Twhere
U: TryFrom<T>,
© 2010 The Rust Project Developers
Licensed under the Apache License, Version 2.0 or the MIT license, at your option.
https://doc.rust-lang.org/std/sync/nonpoison/struct.RwLockWriteGuard.html