Struct ReentrantLock

struct ReentrantLock<T: ?Sized> { ... }

A re-entrant mutual exclusion lock

This lock will block other threads waiting for the lock to become available. The thread which has already locked the mutex can lock it multiple times without blocking, preventing a common source of deadlocks.

Examples

Allow recursively calling a function needing synchronization from within a callback (this is how StdoutLock is currently implemented):

#![feature(reentrant_lock)]

use std::cell::RefCell;
use std::sync::ReentrantLock;

pub struct Log {
    data: RefCell<String>,
}

impl Log {
    pub fn append(&self, msg: &str) {
        self.data.borrow_mut().push_str(msg);
    }
}

static LOG: ReentrantLock<Log> = ReentrantLock::new(Log { data: RefCell::new(String::new()) });

pub fn with_log<R>(f: impl FnOnce(&Log) -> R) -> R {
    let log = LOG.lock();
    f(&*log)
}

with_log(|log| {
    log.append("Hello");
    with_log(|log| log.append(" there!"));
});

Implementations

impl<T> ReentrantLock<T>

const fn new(t: T) -> ReentrantLock<T>

Creates a new re-entrant lock in an unlocked state ready for use.

Examples

#![feature(reentrant_lock)]
use std::sync::ReentrantLock;

let lock = ReentrantLock::new(0);
fn into_inner(self: Self) -> T

Consumes this lock, returning the underlying data.

Examples

#![feature(reentrant_lock)]

use std::sync::ReentrantLock;

let lock = ReentrantLock::new(0);
assert_eq!(lock.into_inner(), 0);

impl<T: ?Sized> ReentrantLock<T>

fn lock(self: &Self) -> ReentrantLockGuard<'_, T>

Acquires the lock, blocking the current thread until it is able to do so.

This function will block the caller until it is available to acquire the lock. Upon returning, the thread is the only thread with the lock held. When the thread calling this method already holds the lock, the call succeeds without blocking.

Examples

#![feature(reentrant_lock)]
use std::cell::Cell;
use std::sync::{Arc, ReentrantLock};
use std::thread;

let lock = Arc::new(ReentrantLock::new(Cell::new(0)));
let c_lock = Arc::clone(&lock);

thread::spawn(move || {
    c_lock.lock().set(10);
}).join().expect("thread::spawn failed");
assert_eq!(lock.lock().get(), 10);
fn get_mut(self: &mut Self) -> &mut T

Returns a mutable reference to the underlying data.

Since this call borrows the ReentrantLock mutably, no actual locking needs to take place -- the mutable borrow statically guarantees no locks exist.

Examples

#![feature(reentrant_lock)]
use std::sync::ReentrantLock;

let mut lock = ReentrantLock::new(0);
*lock.get_mut() = 10;
assert_eq!(*lock.lock(), 10);
const fn data_ptr(self: &Self) -> *const T

Returns a raw pointer to the underlying data.

The returned pointer is always non-null and properly aligned, but it is the user's responsibility to ensure that any reads through it are properly synchronized to avoid data races, and that it is not read through after the lock is dropped.

impl<T> Any for ReentrantLock<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ReentrantLock<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ReentrantLock<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Freeze for ReentrantLock<T>

impl<T> From for ReentrantLock<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> From for ReentrantLock<T>

fn from(t: T) -> Self

impl<T> From for ReentrantLock<T>

fn from(t: never) -> T

impl<T> Unpin for ReentrantLock<T>

impl<T> UnsafeUnpin for ReentrantLock<T>

impl<T, U> Into for ReentrantLock<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ReentrantLock<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ReentrantLock<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: Default> Default for ReentrantLock<T>

fn default() -> Self

impl<T: RefUnwindSafe + ?Sized> RefUnwindSafe for ReentrantLock<T>

impl<T: Send + ?Sized> Send for ReentrantLock<T>

impl<T: Send + ?Sized> Sync for ReentrantLock<T>

impl<T: UnwindSafe + ?Sized> UnwindSafe for ReentrantLock<T>

impl<T: fmt::Debug + ?Sized> Debug for ReentrantLock<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result