Struct ReentrantLock
struct ReentrantLock<T: ?Sized> { ... }
A re-entrant mutual exclusion lock
This lock will block other threads waiting for the lock to become available. The thread which has already locked the mutex can lock it multiple times without blocking, preventing a common source of deadlocks.
Examples
Allow recursively calling a function needing synchronization from within
a callback (this is how StdoutLock is currently
implemented):
use RefCell;
use ReentrantLock;
static LOG: = new;
with_log;
Implementations
impl<T> ReentrantLock<T>
const fn new(t: T) -> ReentrantLock<T>Creates a new re-entrant lock in an unlocked state ready for use.
Examples
use ReentrantLock; let lock = new;fn into_inner(self: Self) -> TConsumes this lock, returning the underlying data.
Examples
use ReentrantLock; let lock = new; assert_eq!;
impl<T: ?Sized> ReentrantLock<T>
fn lock(self: &Self) -> ReentrantLockGuard<'_, T>Acquires the lock, blocking the current thread until it is able to do so.
This function will block the caller until it is available to acquire the lock. Upon returning, the thread is the only thread with the lock held. When the thread calling this method already holds the lock, the call succeeds without blocking.
Examples
use Cell; use ; use thread; let lock = new; let c_lock = clone; spawn.join.expect; assert_eq!;fn get_mut(self: &mut Self) -> &mut TReturns a mutable reference to the underlying data.
Since this call borrows the
ReentrantLockmutably, no actual locking needs to take place -- the mutable borrow statically guarantees no locks exist.Examples
use ReentrantLock; let mut lock = new; *lock.get_mut = 10; assert_eq!;const fn data_ptr(self: &Self) -> *const TReturns a raw pointer to the underlying data.
The returned pointer is always non-null and properly aligned, but it is the user's responsibility to ensure that any reads through it are properly synchronized to avoid data races, and that it is not read through after the lock is dropped.
impl<T> Any for ReentrantLock<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ReentrantLock<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ReentrantLock<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for ReentrantLock<T>
impl<T> From for ReentrantLock<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> From for ReentrantLock<T>
fn from(t: T) -> Self
impl<T> From for ReentrantLock<T>
fn from(t: never) -> T
impl<T> Unpin for ReentrantLock<T>
impl<T> UnsafeUnpin for ReentrantLock<T>
impl<T, U> Into for ReentrantLock<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ReentrantLock<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ReentrantLock<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: Default> Default for ReentrantLock<T>
fn default() -> Self
impl<T: RefUnwindSafe + ?Sized> RefUnwindSafe for ReentrantLock<T>
impl<T: Send + ?Sized> Send for ReentrantLock<T>
impl<T: Send + ?Sized> Sync for ReentrantLock<T>
impl<T: UnwindSafe + ?Sized> UnwindSafe for ReentrantLock<T>
impl<T: fmt::Debug + ?Sized> Debug for ReentrantLock<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result