Function current
fn current() -> Thread
Gets a handle to the thread that invokes it.
Examples
Getting a handle to the current thread with thread::current():
use thread;
let handler = new
.name
.spawn
.unwrap;
handler.join.unwrap;