Struct JoinHandle

struct JoinHandle<T>(_)

An owned permission to join on a thread (block on its termination).

A JoinHandle detaches the associated thread when it is dropped, which means that there is no longer any handle to the thread and no way to join on it.

Due to platform restrictions, it is not possible to Clone this handle: the ability to join a thread is a uniquely-owned permission.

This struct is created by the thread::spawn function and the thread::Builder::spawn method.

Examples

Creation from thread::spawn:

use std::thread;

let join_handle: thread::JoinHandle<_> = thread::spawn(|| {
    // some work here
});

Creation from thread::Builder::spawn:

use std::thread;

let builder = thread::Builder::new();

let join_handle: thread::JoinHandle<_> = builder.spawn(|| {
    // some work here
}).unwrap();

A thread being detached and outliving the thread that spawned it:

use std::thread;
use std::time::Duration;

let original_thread = thread::spawn(|| {
    let _detached_thread = thread::spawn(|| {
        // Here we sleep to make sure that the first thread returns before.
        thread::sleep(Duration::from_millis(10));
        // This will be called, even though the JoinHandle is dropped.
        println!("♫ Still alive ♫");
    });
});

original_thread.join().expect("The thread being joined has panicked");
println!("Original thread is joined.");

// We make sure that the new thread has time to run, before the main
// thread returns.

thread::sleep(Duration::from_millis(1000));

Implementations

impl<T> JoinHandle<T>

fn thread(self: &Self) -> &Thread

Extracts a handle to the underlying thread.

Examples

use std::thread;

let builder = thread::Builder::new();

let join_handle: thread::JoinHandle<_> = builder.spawn(|| {
    // some work here
}).unwrap();

let thread = join_handle.thread();
println!("thread id: {:?}", thread.id());
fn join(self: Self) -> Result<T>

Waits for the associated thread to finish.

This function will return immediately if the associated thread has already finished. Otherwise, it fully waits for the thread to finish, including all destructors for thread-local variables that might be running after the main function of the thread.

In terms of atomic memory orderings, the completion of the associated thread synchronizes with this function returning. In other words, all operations performed by that thread happen before all operations that happen after join returns.

If the associated thread panics, Err is returned with the parameter given to [panic!] (though see the Notes below).

Panics

This function may panic on some platforms if a thread attempts to join itself or otherwise may create a deadlock with joining threads.

Examples

use std::thread;

let builder = thread::Builder::new();

let join_handle: thread::JoinHandle<_> = builder.spawn(|| {
    // some work here
}).unwrap();
join_handle.join().expect("Couldn't join on the associated thread");

Notes

If a "foreign" unwinding operation (e.g. an exception thrown from C++ code, or a panic! in Rust code compiled or linked with a different runtime) unwinds all the way to the thread root, the process may be aborted; see the Notes on thread::spawn. If the process is not aborted, this function will return a Result::Err containing an opaque type.

fn is_finished(self: &Self) -> bool

Checks if the associated thread has finished running its main function.

is_finished supports implementing a non-blocking join operation, by checking is_finished, and calling join if it returns true. This function does not block. To block while waiting on the thread to finish, use [join][Self::join].

This might return true for a brief moment after the thread's main function has returned, but before the thread itself has stopped running. However, once this returns true, [join][Self::join] can be expected to return quickly, without blocking for any significant amount of time.

impl<T> Any for JoinHandle<T>

fn type_id(self: &Self) -> TypeId

impl<T> AsHandle for JoinHandle<T>

fn as_handle(self: &Self) -> BorrowedHandle<'_>

impl<T> AsRawHandle for JoinHandle<T>

fn as_raw_handle(self: &Self) -> RawHandle

impl<T> Borrow for JoinHandle<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for JoinHandle<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Debug for JoinHandle<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Freeze for JoinHandle<T>

impl<T> From for JoinHandle<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoRawHandle for JoinHandle<T>

fn into_raw_handle(self: Self) -> RawHandle

impl<T> JoinHandleExt for JoinHandle<T>

fn as_pthread_t(self: &Self) -> RawPthread
fn into_pthread_t(self: Self) -> RawPthread

impl<T> RefUnwindSafe for JoinHandle<T>

impl<T> Send for JoinHandle<T>

impl<T> Sync for JoinHandle<T>

impl<T> Unpin for JoinHandle<T>

impl<T> UnsafeUnpin for JoinHandle<T>

impl<T> UnwindSafe for JoinHandle<T>

impl<T, U> Into for JoinHandle<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for JoinHandle<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for JoinHandle<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>